@@ -106,7 +106,9 @@ var cell2 = riga.insertCell(-1);
 var cell3 = riga.insertCell(-1);
 cell1.width = '34px';
 cell1.height = '34px';
-cell1.innerHTML = '<button class=\"pos\" type=\"submit\" name=\"canc_costo\" value=\"'+ultimo_costo+'\" onclick=\"return canc_cos_pv('+ultimo_costo+');\" style=\"padding: 0;\"><img style=\"display: block; padding: 0; border: 0; margin: 0;\" src=\".\/img\/croce.gif\" alt=\"X\"><\/button>';
+var html_button = '<button class=\"pos\" type=\"submit\" name=\"canc_costo\" value=\"'+ultimo_costo+'\" onclick=\"return canc_cos_pv('+ultimo_costo;
+html_button += ');\" style=\"padding: 0;\"><img style=\"display: block; padding: 0; border: 0; margin: 0;\" src=\".\/img\/croce.gif\" alt=\"X\"><\/button>';
+cell1.innerHTML = html_button;
 cell2.innerHTML = nome;
 if (molt && molt != 1) cell2.innerHTML += ' <b>x'+molt+'<\/b>';
 cell3.width = '40px';
