@@ -48,9 +48,12 @@ $mess_dati_form .= "<input type=\"hidden\" name=\"tipo_sconto$n_t\" value=\"".${
 <input type=\"hidden\" name=\"giorno_stima_checkin$n_t\" value=\"".${"giorno_stima_checkin".$n_t}."\">
 <input type=\"hidden\" name=\"ora_stima_checkin$n_t\" value=\"".${"ora_stima_checkin".$n_t}."\">
 <input type=\"hidden\" name=\"min_stima_checkin$n_t\" value=\"".${"min_stima_checkin".$n_t}."\">
-<input type=\"hidden\" name=\"tipo_commento$n_t\" value=\"".${"tipo_commento".$n_t}."\">";
-if (!@get_magic_quotes_gpc()) $mess_dati_form .= "<input type=\"hidden\" name=\"commento$n_t\" value=\"".htmlspecialchars(${"commento".$n_t})."\">";
-else $mess_dati_form .= "<input type=\"hidden\" name=\"commento$n_t\" value=\"".htmlspecialchars(stripslashes(${"commento".$n_t}))."\">";
+<input type=\"hidden\" name=\"num_commenti$n_t\" value=\"".${"num_commenti".$n_t}."\">";
+for ($num_comm = 1 ; $num_comm <= ${"num_commenti".$n_t} ; $num_comm++) {
+$mess_dati_form .= "<input type=\"hidden\" name=\"tipo_commento$num_comm"."_$n_t\" value=\"".${"tipo_commento".$num_comm."_".$n_t}."\">";
+if (!@get_magic_quotes_gpc()) $mess_dati_form .= "<input type=\"hidden\" name=\"commento$num_comm"."_$n_t\" value=\"".htmlspecialchars(${"commento".$num_comm."_".$n_t})."\">";
+else $mess_dati_form .= "<input type=\"hidden\" name=\"commento$num_comm"."_$n_t\" value=\"".htmlspecialchars(stripslashes(${"commento".$num_comm."_".$n_t}))."\">";
+} # fine for $num_comm
 if (!@get_magic_quotes_gpc()) $mess_dati_form .= "<input type=\"hidden\" name=\"met_paga_caparra$n_t\" value=\"".htmlspecialchars(${"met_paga_caparra".$n_t})."\">";
 else $mess_dati_form .= "<input type=\"hidden\" name=\"met_paga_caparra$n_t\" value=\"".htmlspecialchars(stripslashes(${"met_paga_caparra".$n_t}))."\">";
 if (!@get_magic_quotes_gpc()) $mess_dati_form .= "<input type=\"hidden\" name=\"origine_prenota$n_t\" value=\"".htmlspecialchars(${"origine_prenota".$n_t})."\">";
