@@ -76,14 +76,163 @@ $files_sorgente = array(
 'doc/README.translation',
 'doc/TODO',
 'img/',
+'img/addbackup.png',
+'img/adddocument.png',
+'img/addextracost.png',
+'img/addinventory.png',
+'img/addmonths.png',
+'img/addphoto.png',
+'img/addroom.png',
+'img/adduser.png',
+'img/backmenu.png',
+'img/backup_mini.png',
+'img/backup.png',
+'img/button28.gif',
+'img/button.gif',
+'img/cancel_mini.png',
+'img/cancel.png',
+'img/cbackup.png',
+'img/cclient.png',
+'img/ccreditcard.png',
+'img/cdocument.png',
+'img/cexpenses.png',
+'img/cextracost.png',
+'img/check_avail.png',
+'img/cinventory.png',
+'img/client_mini.png',
+'img/client.png',
+'img/cmonths.png',
+'img/configure_mini.png',
+'img/configure.png',
+'img/cphoto.png',
+'img/creditcard_mini.png',
+'img/creditcard.png',
+'img/creserv.png',
+'img/creservs.png',
+'img/crespayment.png',
 'img/croce.gif',
+'img/croom.png',
+'img/crule.png',
+'img/ctaxes.png',
+'img/dir1_des.png',
+'img/dir1_sin.png',
+'img/dir2_des.png',
+'img/dir2_sin.png',
+'img/dir3_des.png',
+'img/dir3_sin.png',
+'img/docbackup.png',
+'img/documents_mini.png',
+'img/documents.png',
+'img/downbackup.png',
+'img/edit2_mini.png',
+'img/edit_mini.png',
+'img/edit.png',
+'img/emailsend.png',
+'img/emails_mini.png',
+'img/expenses.png',
+'img/expinc.png',
+'img/extracosts_mini.png',
+'img/extracosts.png',
 'img/favicon.ico',
 'img/freccia_destra_marg.png',
 'img/freccia_giu_marg.png',
+'img/freccia_sinistra_marg.png',
 'img/freccia_su_marg.png',
 'img/fr_sx_checkin.gif',
 'img/fr_sx_rossa.gif',
+'img/goarrow_mini.png',
+'img/goarrow.png',
+'img/goarrow_xmini.png',
+'img/goback.png',
+'img/guests2.png',
+'img/guests.png',
+'img/iclient.png',
+'img/iexpense.png',
+'img/iexpenses.png',
+'img/iincome.png',
+'img/incomes_mini.png',
+'img/incomes.png',
+'img/interconn_mini.png',
+'img/interconn.png',
+'img/inventory_mini.png',
+'img/inventory.png',
+'img/iprices.png',
+'img/ireserv_mini.png',
+'img/ireserv.png',
+'img/irules.png',
+'img/key_mini.png',
+'img/key.png',
 'img/logo.png',
+'img/mclient.png',
+'img/menu_mini.png',
+'img/menu.png',
+'img/messages_mini.png',
+'img/messages.png',
+'img/minventory.png',
+'img/month1_mini.png',
+'img/month2_mini.png',
+'img/month3_mini.png',
+'img/month4_mini.png',
+'img/month_mini.png',
+'img/month.png',
+'img/mprices.png',
+'img/mreserv.png',
+'img/mreservs.png',
+'img/mroom.png',
+'img/muser.png',
+'img/next.png',
+'img/ok.png',
+'img/plus_mini.png',
+'img/plus.png',
+'img/pos_mini.png',
+'img/pos.png',
+'img/prev.png',
+'img/prices_mini.png',
+'img/print.png',
+'img/rates.png',
+'img/resall_mini.png',
+'img/resarrivals_mini.png',
+'img/rescurrent_mini.png',
+'img/resdepartures_mini.png',
+'img/resdepcurr_mini.png',
+'img/resdocbackup.png',
+'img/reservations_mini.png',
+'img/reservations.png',
+'img/respayments_mini.png',
+'img/respayments.png',
+'img/restorebackup.png',
+'img/rooms_mini.png',
+'img/roomsnear.png',
+'img/rooms.png',
+'img/ruleperiod.png',
+'img/rules_mini.png',
+'img/rules.png',
+'img/search_mini.png',
+'img/selected_mini.png',
+'img/selected.png',
+'img/send.png',
+'img/statistics_mini.png',
+'img/statistics.png',
+'img/stockroom.png',
+'img/table.png',
+'img/tables_mini.png',
+'img/taxes_mini.png',
+'img/taxes.png',
+'img/taxperiod.png',
+'img/upbackup.png',
+'img/upload_mini.png',
+'img/users_mini.png',
+'img/users.png',
+'img/website_mini.png',
+'img/website.png',
+'img/websites.png',
+'img/xclient.png',
+'img/xdocument.png',
+'img/xextracost.png',
+'img/xinventory.png',
+'img/xprices.png',
+'img/xuser.png',
+
 'includes/',
 'includes/costanti.php',
 'includes/dati_form_prenotazione.php',
@@ -246,10 +395,10 @@ $files_sorgente = array(
 'themes/sim/img/',
 'themes/sim/img/bar_bg_bot.png',
 'themes/sim/img/bar_bg_top.png',
-'themes/sim/img/button.gif',
 'themes/sim/img/calpick.png',
 'themes/sim/inc/',
 'themes/sim/inc/functions.js',
+'themes/sim/inc/mobile.css',
 'themes/sim/inc/paper.css',
 'themes/sim/inc/screen.css',
 'themes/sim/inc/stylesheet.css',
@@ -264,7 +413,6 @@ $files_sorgente = array(
 'themes/snj/img/',
 'themes/snj/img/bar_bg_bot.png',
 'themes/snj/img/bar_bg_top.png',
-'themes/snj/img/button.gif',
 'themes/snj/php/',
 'themes/snj/php/foot.php',
 'themes/snj/php/head.php',
