@@ -476,6 +476,8 @@ $app_agenzia = risul_query($regole_prec,$num1,'app_agenzia');
 $tariffa_chiusa = risul_query($regole_prec,$num1,'tariffa_chiusa');
 $tariffa_commissioni = risul_query($regole_prec,$num1,'tariffa_commissioni');
 $iddatainizio = risul_query($regole_prec,$num1,'iddatainizio');
+$motivazione = risul_query($regole_prec,$num1,'motivazione');
+$motivazione2 = risul_query($regole_prec,$num1,'motivazione2');
 if ($iddatainizio < $id_data_ini_periodi_prec) { $iddatainizio = $id_data_ini_periodi_prec; }
 $iddatainizio = $iddatainizio - $id_data_ini_periodi_prec + 1;
 $iddatafine = risul_query($regole_prec,$num1,'iddatafine');
@@ -486,6 +488,8 @@ else {
 if ($tariffa_chiusa) esegui_query("insert into $tableregole (idregole,tariffa_chiusa,iddatainizio,iddatafine) values ('$idregole','$tariffa_chiusa','$iddatainizio','$iddatafine') ");
 else esegui_query("insert into $tableregole (idregole,app_agenzia,iddatainizio,iddatafine) values ('$idregole','$app_agenzia','$iddatainizio','$iddatafine') ");
 } # fine else $tariffa_commissioni)
+if (strcmp($motivazione,"")) esegui_query("update $tableregole set motivazione = '".aggslashdb($motivazione)."' where idregole = '$idregole' ");
+if (strcmp($motivazione2,"")) esegui_query("update $tableregole set motivazione2 = '".aggslashdb($motivazione2)."' where idregole = '$idregole' ");
 } # fine for $num1
 
 $soldi_importati = esegui_query("select * from $tablesoldi_prec where data_inserimento >= '$data_inizio_periodi' and  saldo_prenota is not NULL order by idsoldi");
@@ -651,7 +655,7 @@ unlink($dir_salva."/crea_contr.lock");
 } # fine else if ($num_periodo_interferenza == 0)
 
 
-$colonne = "idntariffe,nomecostoagg,tipo_ca,valore_ca,valore_perc_ca,arrotonda_ca,tasseperc_ca,associasett_ca,numsett_ca,moltiplica_ca,periodipermessi_ca,beniinv_ca,appincompatibili_ca,variazione_ca,mostra_ca,letto_ca,numlimite_ca,regoleassegna_ca,utente_inserimento";
+$colonne = "idntariffe,nomecostoagg,tipo_ca,valore_ca,valore_perc_ca,arrotonda_ca,tasseperc_ca,associasett_ca,numsett_ca,moltiplica_ca,periodipermessi_ca,beniinv_ca,appincompatibili_ca,variazione_ca,mostra_ca,categoria_ca,letto_ca,numlimite_ca,regoleassegna_ca,utente_inserimento";
 for ($num1 = 1 ; $num1 <= $num_tariffe_tab ; $num1++) {
 $nome_nuova_tariffa = "tariffa" . $num1;
 $colonne .= ",$nome_nuova_tariffa";
