@@ -99,21 +99,21 @@ else {
 $idclienti = esegui_query("select max(idclienti) from $tableclienti");
 $idclienti = risul_query($idclienti,0,0) + 1;
 } # fine else if (numlin_query($idclienti) == 0)
-$cognome_maius = ucwords($cognome);
+$cognome_maius = trim(ucwords($cognome));
 if ($attiva_prefisso_clienti == "p") $cognome_maius = $prefisso_clienti.$cognome_maius;
 if ($attiva_prefisso_clienti == "s") $cognome_maius = $cognome_maius.$prefisso_clienti;
 $cognome_maius = aggslashdb($cognome_maius);
 esegui_query("insert into $tableclienti (idclienti,cognome,idclienti_compagni,datainserimento,hostinserimento,utente_inserimento) values ('$idclienti','$cognome_maius',',','$datainserimento','$HOSTNAME','$id_utente_ins')");
 } # fine if (!$idclienti)
 elseif ($cognome) {
-$cognome_maius = ucwords($cognome);
+$cognome_maius = trim(ucwords($cognome));
 if ($attiva_prefisso_clienti == "p") $cognome_maius = $prefisso_clienti.$cognome_maius;
 if ($attiva_prefisso_clienti == "s") $cognome_maius = $cognome_maius.$prefisso_clienti;
 $cognome_maius = aggslashdb($cognome_maius);
 esegui_query("update $tableclienti set cognome = '$cognome_maius' where idclienti = '$idclienti' ");
 } # fine elseif ($cognome)
 if ($nome) {
-$nome_maius = ucwords($nome);
+$nome_maius = trim(ucwords($nome));
 $nome_maius = aggslashdb($nome_maius);
 esegui_query("update $tableclienti set nome = '$nome_maius' where idclienti = '$idclienti' ");
 } # fine if ($nome)
@@ -146,17 +146,17 @@ $datanascita = aggslashdb($datanascita);
 esegui_query("update $tableclienti set datanascita = '$datanascita' where idclienti = '$idclienti' ");
 } # fine if ($mesenascita and ...
 if ($nazionenascita) {
-$nazionenascita_maius = ucwords($nazionenascita);
+$nazionenascita_maius = trim(ucwords($nazionenascita));
 $nazionenascita_maius = aggslashdb($nazionenascita_maius);
 esegui_query("update $tableclienti set nazionenascita = '$nazionenascita_maius' where idclienti = '$idclienti' ");
 } # fine if ($nazionenascita)
 if ($cittanascita) {
-$cittanascita_maius = ucwords($cittanascita);
+$cittanascita_maius = trim(ucwords($cittanascita));
 $cittanascita_maius = aggslashdb($cittanascita_maius);
 esegui_query("update $tableclienti set cittanascita = '$cittanascita_maius' where idclienti = '$idclienti' ");
 } # fine if ($cittanascita)
 if ($regionenascita) {
-$regionenascita_maius = ucwords($regionenascita);
+$regionenascita_maius = trim(ucwords($regionenascita));
 $regionenascita_maius = aggslashdb($regionenascita_maius);
 esegui_query("update $tableclienti set regionenascita = '$regionenascita_maius' where idclienti = '$idclienti' ");
 } # fine if ($regionenascita)
@@ -171,22 +171,22 @@ $datascaddoc = aggslashdb($datascaddoc);
 esegui_query("update $tableclienti set scadenzadoc = '$datascaddoc' where idclienti = '$idclienti' ");
 } # fine if ($mesescaddoc and ...
 if ($nazionedoc) {
-$nazionedoc_maius = ucwords($nazionedoc);
+$nazionedoc_maius = trim(ucwords($nazionedoc));
 $nazionedoc_maius = aggslashdb($nazionedoc_maius);
 esegui_query("update $tableclienti set nazionedoc = '$nazionedoc_maius' where idclienti = '$idclienti' ");
 } # fine if ($nazionedoc)
 if ($cittadoc) {
-$cittadoc_maius = ucwords($cittadoc);
+$cittadoc_maius = trim(ucwords($cittadoc));
 $cittadoc_maius = aggslashdb($cittadoc_maius);
 esegui_query("update $tableclienti set cittadoc = '$cittadoc_maius' where idclienti = '$idclienti' ");
 } # fine if ($cittadoc)
 if ($regionedoc) {
-$regionedoc_maius = ucwords($regionedoc);
+$regionedoc_maius = trim(ucwords($regionedoc));
 $regionedoc_maius = aggslashdb($regionedoc_maius);
 esegui_query("update $tableclienti set regionedoc = '$regionedoc_maius' where idclienti = '$idclienti' ");
 } # fine if ($regionedoc)
 if ($nazionalita) {
-$nazionalita_maius = ucwords($nazionalita);
+$nazionalita_maius = trim(ucwords($nazionalita));
 $nazionalita_maius = aggslashdb($nazionalita_maius);
 esegui_query("update $tableclienti set nazionalita = '$nazionalita_maius' where idclienti = '$idclienti' ");
 } # fine if ($nazionalita)
@@ -200,17 +200,17 @@ else $lingua_cli = "";
 else $lingua_cli = "";
 } # fine if ($lingua_cli)
 if ($nazione) {
-$nazione_maius = ucwords($nazione);
+$nazione_maius = trim(ucwords($nazione));
 $nazione_maius = aggslashdb($nazione_maius);
 esegui_query("update $tableclienti set nazione = '$nazione_maius' where idclienti = '$idclienti' ");
 } # fine if ($nazione)
 if ($citta) {
-$citta_maius = ucwords($citta);
+$citta_maius = trim(ucwords($citta));
 $citta_maius = aggslashdb($citta_maius);
 esegui_query("update $tableclienti set citta = '$citta_maius' where idclienti = '$idclienti' ");
 } # fine if ($citta)
 if ($regione) {
-$regione_maius = ucwords($regione);
+$regione_maius = trim(ucwords($regione));
 $regione_maius = aggslashdb($regione_maius);
 esegui_query("update $tableclienti set regione = '$regione_maius' where idclienti = '$idclienti' ");
 } # fine if ($regione)
@@ -218,7 +218,7 @@ if ($nomevia) {
 if ($lingua_mex != "ita") include("./includes/lang/$lingua_mex/ordine_frasi.php");
 if ($ordine_strada == 2) $via = $nomevia . " " . $via;
 else $via = $via . " " . $nomevia;
-$via_maius = ucwords($via);
+$via_maius = trim(ucwords($via));
 $via_maius = aggslashdb($via_maius);
 esegui_query("update $tableclienti set via = '$via_maius' where idclienti = '$idclienti' ");
 } # fine if ($nomevia)
@@ -256,7 +256,7 @@ return $idclienti;
 
 
 
-function mostra_dati_cliente ($dati_cliente,&$dcognome,&$dnome,&$dsoprannome,&$dtitolo_cli,&$dsesso,&$ddatanascita,&$ddatanascita_f,&$dnazionenascita,&$dcittanascita,&$dregionenascita,&$ddocumento,&$dscadenzadoc,&$dscadenzadoc_f,&$dtipodoc,&$dnazionedoc,&$dregionedoc,&$dcittadoc,&$dnazionalita,&$dlingua_cli,&$dnazione,&$dregione,&$dcitta,&$dvia,&$dnumcivico,&$dtelefono,&$dtelefono2,&$dtelefono3,&$dfax,&$dcap,&$demail,&$dcod_fiscale,&$dpartita_iva,$mostra_num="",$priv_ins_clienti="",$silenzio="") {
+function mostra_dati_cliente (&$dati_cliente,&$dcognome,&$dnome,&$dsoprannome,&$dtitolo_cli,&$dsesso,&$ddatanascita,&$ddatanascita_f,&$dnazionenascita,&$dcittanascita,&$dregionenascita,&$ddocumento,&$dscadenzadoc,&$dscadenzadoc_f,&$dtipodoc,&$dnazionedoc,&$dregionedoc,&$dcittadoc,&$dnazionalita,&$dlingua_cli,&$dnazione,&$dregione,&$dcitta,&$dvia,&$dnumcivico,&$dtelefono,&$dtelefono2,&$dtelefono3,&$dfax,&$dcap,&$demail,&$dcod_fiscale,&$dpartita_iva,$mostra_num="",$priv_ins_clienti="",$silenzio="",$mostra_commento="") {
 global $pag,$id_utente,$PHPR_TAB_PRE;
 
 if ($id_utente == 1 or !$id_utente) {
@@ -309,6 +309,8 @@ $demail = risul_query($dati_cliente,0,'email');
 } # fine if ($priv_vedi_telefoni == "s")
 $dcod_fiscale = risul_query($dati_cliente,0,'cod_fiscale');
 $dpartita_iva = risul_query($dati_cliente,0,'partita_iva');
+if ($mostra_commento) $dcommento = risul_query($dati_cliente,0,'commento');
+else $dcommento = "";
 
 if ($dlingua_cli) {
 if ($dlingua_cli == "ita") $d_nome_lingua = "Italiano";
@@ -402,6 +404,9 @@ if ($dcod_fiscale and $dpartita_iva) $lin .= ", ";
 if ($dpartita_iva) $lin .= mex("Partita iva",$pag).": $dpartita_iva ";
 if ($lin) $output .= "<br>$lin";
 
+if ($dcommento) $output = "<div style=\"float: left; padding: 0 60px 0 0;\">$output</div>
+<div style=\"float: left; max-width: 400px;\"><br>".mex("Commento",$pag).": $dcommento</div><div style=\"clear: both;\"></div>";
+
 if (!$silenzio) echo $output;
 else return $output;
 
