@@ -76,6 +76,7 @@ if ($dati_ca[$num1]['numsett'] == "g") $dati_ca[$num1]['giornisett'] = substr($n
 $dati_ca[$num1]['mostra'] = risul_query($costi,$num1,'mostra_ca');
 $dati_ca[$num1]['raggruppa'] = substr($dati_ca[$num1]['mostra'],1,1);
 $dati_ca[$num1]['combina'] = substr($dati_ca[$num1]['mostra'],2,1);
+$dati_ca[$num1]['escludi_tot_perc'] = substr($dati_ca[$num1]['mostra'],3,1);
 $dati_ca[$num1]['mostra'] = substr($dati_ca[$num1]['mostra'],0,1);
 $dati_ca[$num1]['moltiplica'] = risul_query($costi,$num1,'moltiplica_ca');
 $dati_ca[$num1]['molt_max'] = substr($dati_ca[$num1]['moltiplica'],1,1);
@@ -222,7 +223,7 @@ return $periodo_costo_trovato;
 
 
 
-function calcola_prezzo_totale_costo ($dati_ca,$num_costo,$idinizioperiodo,$idfineperiodo,$settimane_costo,$moltiplica,$costo_tariffa,$lista_tariffe,$costo_prenota_tot,$caparra,$numpersone) {
+function calcola_prezzo_totale_costo ($dati_ca,$num_costo,$idinizioperiodo,$idfineperiodo,$settimane_costo,$moltiplica,$costo_tariffa,$lista_tariffe,$costo_prenota_tot,$caparra,$numpersone,$costo_escludi_perc=0) {
 
 $prezzo_costo_fisso = (double) $dati_ca[$num_costo]['valore'];
 if ($dati_ca[$num_costo]['tipo_val'] != "f") $prezzo_costo_perc = (double) $dati_ca[$num_costo]['valore_perc'];
@@ -248,9 +249,9 @@ if ($dati_ca[$num_costo]['tipo_val'] == "s") {
 if ($numpersone) $prezzo_costo_perc = (($costo_tariffap / (double) $numpersone) * $prezzo_costo_perc) / 100;
 else $prezzo_costo_perc = 0;
 } # fine if ($dati_ca[$num_costo]['tipo_val'] == "s")
-if ($dati_ca[$num_costo]['tipo_val'] == "t") $prezzo_costo_perc = ($costo_prenota_tot * $prezzo_costo_perc) / 100;
+if ($dati_ca[$num_costo]['tipo_val'] == "t") $prezzo_costo_perc = (($costo_prenota_tot - (double) $costo_escludi_perc) * $prezzo_costo_perc) / 100;
 if ($dati_ca[$num_costo]['tipo_val'] == "c") $prezzo_costo_perc = ($caparra * $prezzo_costo_perc) / 100;
-if ($dati_ca[$num_costo]['tipo_val'] == "r") $prezzo_costo_perc = (($costo_prenota_tot - $caparra) * $prezzo_costo_perc) / 100;
+if ($dati_ca[$num_costo]['tipo_val'] == "r") $prezzo_costo_perc = ((($costo_prenota_tot - (double) $costo_escludi_perc) - $caparra) * $prezzo_costo_perc) / 100;
 } # fine if ($dati_ca[$num_costo]['tipo'] == "u")
 if ($dati_ca[$num_costo]['tipo'] == "s") {
 if ($dati_ca[$num_costo]['associasett'] == "s") {
@@ -265,10 +266,13 @@ if (str_replace(",".$num1.",","",$settimane_costo) != $settimane_costo) {
 $prezzo_costo_fisso_tot = $prezzo_costo_fisso_tot + ($prezzo_costo_fisso * $moltiplica[$num_sett]);
 if ($dati_ca[$num_costo]['tipo_val'] == "p") $prezzo_costo_sett = ($lista_tariffe[$num_lista_tariffe] * $prezzo_costo_perc) / 100;
 if ($dati_ca[$num_costo]['tipo_val'] == "q") $prezzo_costo_sett = (($lista_tariffe[$num_lista_tariffe] - $lista_tariffep[$num_lista_tariffe]) * $prezzo_costo_perc) / 100;
-if ($dati_ca[$num_costo]['tipo_val'] == "s") $prezzo_costo_sett = ($lista_tariffep[$num_lista_tariffe] * $prezzo_costo_perc) / 100;
+if ($dati_ca[$num_costo]['tipo_val'] == "s") {
+if ($numpersone) $prezzo_costo_sett = (($lista_tariffep[$num_lista_tariffe] / (double) $numpersone) * $prezzo_costo_perc) / 100;
+else $prezzo_costo_sett = 0;
+} # fine if ($dati_ca[$num_costo]['tipo_val'] == "s")
 $prezzo_costo_perc_tot = $prezzo_costo_perc_tot + ($prezzo_costo_sett * $moltiplica[$num_sett]);
 $num_sett++;
-} # fine (str_replace(",".$num1.",","",$settimane_costo) != $settimane_costo)
+} # fine if (str_replace(",".$num1.",","",$settimane_costo) != $settimane_costo)
 $num_lista_tariffe++;
 } # fine for $num1
 $prezzo_costo_fisso = $prezzo_costo_fisso_tot;
@@ -506,6 +510,8 @@ $dati_cap[$numca]['idntariffe'] = risul_query($costi,$numca,'idntariffe');
 $dati_cap[$numca]['appincompatibili'] = risul_query($costi,$numca,'varappincompatibili');
 $dati_cap[$numca]['categoria'] = risul_query($costi,$numca,'categoria');
 $dati_cap[$numca]['combina'] = risul_query($costi,$numca,'variazione');
+$dati_cap[$numca]['escludi_tot_perc'] = substr($dati_cap[$numca]['combina'],1,1);
+$dati_cap[$numca]['combina'] = substr($dati_cap[$numca]['combina'],0,1);
 $dati_cap[$numca]['tariffeassociate'] = risul_query($costi,$numca,'vartariffeassociate');
 $dati_cap[$numca]['tipo_tariffeassociate'] = substr($dati_cap[$numca]['tariffeassociate'],0,1);
 $dati_cap[$numca]['tariffeassociate'] = substr($dati_cap[$numca]['tariffeassociate'],1);
@@ -666,6 +672,32 @@ esegui_query("update $tablerelinventario set quantita = '$n_num_bene' where idbe
 
 
 
+function aggiorna_privilegi_ins_costo ($idntariffe,$tableprivilegi,$id_utente,$anno,$attiva_costi_agg_consentiti,$priv_ins_costi_agg,$utenti_gruppi) {
+
+if ($attiva_costi_agg_consentiti != "n") {
+$costi_agg_cons_int = esegui_query("select costi_agg_consentiti from $tableprivilegi where idutente = '$id_utente'  and anno = '$anno' ");
+$costi_agg_cons_int = risul_query($costi_agg_cons_int,0,"costi_agg_consentiti");
+esegui_query("update $tableprivilegi set costi_agg_consentiti = '$costi_agg_cons_int,$idntariffe' where idutente = '$id_utente'  and anno = '$anno' ");
+} # fine if ($attiva_costi_agg_consentiti != "n")
+if ($priv_ins_costi_agg == "g") {
+reset($utenti_gruppi);
+while (list($idut_gr,$val) = each($utenti_gruppi)) {
+if ($idut_gr != $id_utente) {
+$costi_agg_cons_int = esegui_query("select costi_agg_consentiti from $tableprivilegi where idutente = '$idut_gr'  and anno = '$anno' ");
+if (numlin_query($costi_agg_cons_int) == 1) {
+$costi_agg_cons_int = risul_query($costi_agg_cons_int,0,'costi_agg_consentiti');
+if (substr($costi_agg_cons_int,0,1) != "n") {
+esegui_query("update $tableprivilegi set costi_agg_consentiti = '$costi_agg_cons_int,$idntariffe' where idutente = '$idut_gr'  and anno = '$anno' ");
+} # fine if (substr($costi_agg_cons_int,0,1) != "n")
+} # fine if (numlin_query($costi_agg_cons_int) == 1)
+} # fine if ($idut_gr != $id_utente)
+} # fine while (list($idut_gr,$val) = each($utenti_gruppi))
+} # fine if ($priv_ins_costi_agg == "g")
+
+} # fine function aggiorna_privilegi_ins_costo
+
+
+
 
 
 ?>
\ No newline at end of file
