@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2013 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2015 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -23,7 +23,7 @@
 
 
 
-function inserisci_prenotazione ($inizioperiodo,$fineperiodo,$lista_app,$tipotariffa,$numpersone,$prenota_vicine,$idclienti,$conferma,$pagato,$caparra,$met_paga_caparra,$commissioni,$origine_prenota,$sconto,$giorno_stima_checkin,$ora_stima_checkin,$min_stima_checkin,$commento,&$stato,$anno,$PHPR_TAB_PRE,$ins_passato="",$id_utente_imp="",$id_prenota_imp="",$tariffe_sett_imp="") {
+function inserisci_prenotazione ($inizioperiodo,$fineperiodo,$lista_app,$tipotariffa,$numpersone,$prenota_vicine,$idclienti,$conferma,$pagato,$caparra,$met_paga_caparra,$commissioni,$origine_prenota,$sconto,$giorno_stima_checkin,$ora_stima_checkin,$min_stima_checkin,$commento,&$stato,$anno,$PHPR_TAB_PRE,$ins_passato="",$id_utente_imp="",$id_prenota_imp="",$tariffe_sett_imp="",$ins_costi_agg="") {
 global $id_utente,$HOSTNAME;
 
 $PHPR_TAB_PRE = aggslashdb($PHPR_TAB_PRE);
@@ -37,8 +37,8 @@ $tablepersonalizza = $PHPR_TAB_PRE."personalizza";
 $tableclienti = $PHPR_TAB_PRE."clienti";
 $tablenometariffe = $PHPR_TAB_PRE."ntariffe".$anno;
 
-if (!function_exists("tab_a_var")) include("./includes/liberasettimane.php");
-if (!function_exists("dati_tariffe")) include("./includes/funzioni_tariffe.php");
+if (!function_exists('tab_a_var')) include("./includes/liberasettimane.php");
+if (!function_exists('dati_tariffe')) include("./includes/funzioni_tariffe.php");
 
 include("./includes/sett_gio.php");
 $Euro = nome_valuta();
@@ -51,7 +51,10 @@ $numappartamenti = numlin_query($appartamenti);
 $id_app_richiesti = 0;
 
 $dati_tariffe = dati_tariffe($tablenometariffe,"","",$tableregole);
-
+if ($ins_costi_agg) {
+if (!function_exists('dati_costi_agg_ntariffe')) include("./includes/funzioni_costi_agg.php");
+$dati_ca = dati_costi_agg_ntariffe($tablenometariffe,$dati_tariffe['num'],"NO","",$tableappartamenti);
+} # fine if ($ins_costi_agg)
 
 for ($n_t = 1 ; $n_t <= $num_tipologie ; $n_t++) {
 
@@ -451,7 +454,7 @@ else $mess_prenota .= mex("$lettera_e","prenota.php");
 $mess_prenota .= ") ".mex("a nome di","prenota.php")." <b>$cognome</b> ";
 if ($numpersone[$n_t]) $mess_prenota .= mex("per",'prenota.php')." <b>".$numpersone[$n_t]."</b> ".mex("persone",'prenota.php')." ";
 $mess_prenota .= mex("nell'appartamento",'unit.php')." <b>".$appartamento[$n_t]."</b>";
-if ($assegnazioneapp[$n_t] == "k") $mess_prenota .= " (".mex("fisso","prenota.php").")";
+if ($assegnazioneapp[$n_t] == "k") $mess_prenota .= " (".mex("fisso","unit.php").")";
 else {
 $mess_prenota .= " (".mex("mobile","prenota.php");
 if ($lista_app[$n_t]) $mess_prenota .= " ".mex("in","prenota.php")." ".str_replace(",",", ",$lista_app[$n_t]);
@@ -577,6 +580,82 @@ if (!$caparra[$n_t] and $met_trovato == "NO") $mess_prenota .= "<br>";
 $mess_prenota .= mex("Commissioni","prenota.php").": <b>$commissioni_p</b> $Euro (".mex("resto commissioni","prenota.php").": $resto_comm_p $Euro).<br>";
 } # fine if ($commissioni[$n_t])
 
+
+# calcolo costi nulli, non letto e senza inventario da associare alla tariffa, tutti come se fossero "se possibile"
+if ($ins_costi_agg == "costi_nulli") {
+unset($num_letti_agg);
+unset($num_costi_presenti);
+$oggi_costo = date("Ymd",(time() + (C_DIFF_ORE * 3600)));
+for ($num_costo = 0 ; $num_costo < $dati_ca['num'] ; $num_costo++) {
+if (!$dati_ca[$num_costo]['valore'] and !$dati_ca[$num_costo]['valore_perc'] and $dati_ca[$num_costo]['letto'] != "s" and !$dati_ca[$num_costo]['tipo_beniinv']) {
+$associa_costo = "NO";
+$associa_costo_tariffa = associa_costo_a_tariffa($dati_ca,$num_costo,$tipotariffa[$n_t],($fineperiodo[$n_t] - $inizioperiodo[$n_t] + 1));
+if ($associa_costo_tariffa == "SI") $associa_costo = "SI";
+if ($associa_costo_tariffa != "SI" and !$dati_ca[$num_costo]["incomp_".$tipotariffa[$n_t]]) {
+if ($dati_ca[$num_costo]['assegna_con_num_prenota'] and count($inizioperiodo) >= $dati_ca[$num_costo]['assegna_con_num_prenota']) $associa_costo = "SI";
+if ($dati_ca[$num_costo]['assegna_da_ini_prenota']) {
+$giorni_lim = substr($dati_ca[$num_costo]['assegna_da_ini_prenota'],1);
+$limite = date("Ymd",mktime(0,0,0,substr($inizioperiodo_orig[$n_t],5,2),(substr($inizioperiodo_orig[$n_t],8,2) - $giorni_lim),substr($inizioperiodo_orig[$n_t],0,4)));
+if (substr($dati_ca[$num_costo]['assegna_da_ini_prenota'],0,1) == ">" and $oggi_costo < $limite) $associa_costo = "SI";
+if (substr($dati_ca[$num_costo]['assegna_da_ini_prenota'],0,1) == "<" and $oggi_costo > $limite) $associa_costo = "SI";
+} # fine if ($dati_ca[$num_costo][assegna_da_ini_prenota])
+} # fine if ($associa_costo_tariffa != "SI" and...
+if ($associa_costo == "SI") {
+#if ($dati_ca[$num_costo][tipo_val] == "q" and $costo_totale_presente = "SI") $associa_costo = "NO";
+$settimane_costo = calcola_settimane_costo($tableperiodi,$dati_ca,$num_costo,$inizioperiodo[$n_t],$fineperiodo[$n_t],"","");
+calcola_moltiplica_costo($dati_ca,$num_costo,$moltiplica,$inizioperiodo[$n_t],$fineperiodo[$n_t],$settimane_costo,"",$numpersone[$n_t],$num_letti_agg);
+$num_costi_presenti_copia = $num_costi_presenti;
+$periodo_costo_trovato = trova_periodo_permesso_costo($dati_ca,$num_costo,$inizioperiodo[$n_t],$fineperiodo[$n_t],$settimane_costo);
+if ($periodo_costo_trovato == "NO") $associa_costo = "NO";
+else if (controlla_num_limite_costo($tablecostiprenota,$tableprenota,$dati_ca,$num_costo,$num_costi_presenti_copia,$inizioperiodo[$n_t],$fineperiodo[$n_t],$settimane_costo,$moltiplica) == "NO") $associa_costo = "NO";
+
+if ($associa_costo == "SI") {
+$num_costi_presenti = $num_costi_presenti_copia;
+$idcostiprenota = esegui_query("select max(idcostiprenota) from $tablecostiprenota");
+$idcostiprenota = risul_query($idcostiprenota,0,0) + 1;
+$tipo_ca = $dati_ca[$num_costo]['tipo'].$dati_ca[$num_costo]['tipo_val'];
+$valore_ca = $dati_ca[$num_costo]['valore'];
+$valore_perc_ca = $dati_ca[$num_costo]['valore_perc'];
+$associasett_ca = $dati_ca[$num_costo]['associasett'];
+if ($dati_ca[$num_costo]['var_percentuale'] != "s" and $dati_ca[$num_costo]['tipo_val'] != "f") {
+$tipo_ca = $dati_ca[$num_costo]['tipo']."f";
+$moltiplica = 1;
+if ($dati_ca[$num_costo]['tipo'] == "s") {
+$settimane_costo = 1;
+$associasett_ca = "n";
+} # fine if ($dati_ca[$num_costo][tipo] == "s")
+} # fine if ($dati_ca[$num_costo][var_percentuale] != "s" and...
+if ($dati_ca[$num_costo]['var_moltiplica'] == "s") $varmoltiplica_ca = $dati_ca[$num_costo]['moltiplica'].$dati_ca[$num_costo]['molt_max'].$dati_ca[$num_costo]['molt_agg'].",".$dati_ca[$num_costo]['molt_max_num'];
+else $varmoltiplica_ca = "cx0,";
+if ($dati_ca[$num_costo]['var_numsett'] == "s") $varnumsett_ca = $dati_ca[$num_costo]['numsett_orig'];
+else $varnumsett_ca = "c";
+if ($dati_ca[$num_costo]['var_periodip'] == "s") $varperiodipermessi_ca = $dati_ca[$num_costo]['periodipermessi_orig'];
+else $varperiodipermessi_ca = "";
+$varbeniinv_ca = "";
+$varappincompatibili_ca = "";
+if ($dati_ca[$num_costo]['var_tariffea'] == "s") $vartariffeassociate_ca = "p".$dati_ca[$num_costo][$tipotariffa[$n_t]];
+else $vartariffeassociate_ca = "";
+$vartariffeincomp_ca = "";
+if ($dati_ca[$num_costo]['var_tariffei'] == "s") {
+for ($numtariffa = 1 ; $numtariffa <= $dati_tariffe['num'] ; $numtariffa++) {
+if ($dati_ca[$num_costo]["incomp_tariffa".$numtariffa] == "i") $vartariffeincomp_ca .= ",".$numtariffa;
+} # fine for $numtariffa
+if ($vartariffeincomp_ca) $vartariffeincomp_ca = substr($vartariffeincomp_ca,1);
+} # fine if ($dati_ca[$num_costo][var_tariffei] == "s")
+if ($dati_ca[$num_costo]['var_comb'] == "s") $variazione_ca = $dati_ca[$num_costo]['combina'];
+else $variazione_ca = "n";
+$variazione_ca .= $dati_ca[$num_costo]['escludi_tot_perc'];
+esegui_query("insert into $tablecostiprenota (idcostiprenota,idprenota,tipo,nome,valore,associasett,settimane,moltiplica,letto,idntariffe,variazione,varmoltiplica,varnumsett,varperiodipermessi,varbeniinv,varappincompatibili,vartariffeassociate,vartariffeincomp,datainserimento,hostinserimento,utente_inserimento) values ('$idcostiprenota','$idprenota','$tipo_ca','".aggslashdb($dati_ca[$num_costo]['nome'])."','$valore_ca','$associasett_ca','$settimane_costo','$moltiplica','".$dati_ca[$num_costo]['letto']."','".$dati_ca[$num_costo]['id']."','$variazione_ca','$varmoltiplica_ca','$varnumsett_ca','$varperiodipermessi_ca','$varbeniinv_ca','$varappincompatibili_ca','$vartariffeassociate_ca','$vartariffeincomp_ca','$datainserimento','$HOSTNAME','$id_utente_ins')");
+if (substr($tipo_ca,1,1) != "f") esegui_query("update $tablecostiprenota set valore_perc = '$valore_perc_ca', arrotonda = '".$dati_ca[$num_costo]['arrotonda']."' where idcostiprenota = '$idcostiprenota'");
+if ($dati_ca[$num_costo]['tasseperc']) esegui_query("update $tablecostiprenota set tasseperc = '".$dati_ca[$num_costo]['tasseperc']."' where idcostiprenota = '$idcostiprenota'");
+if (strcmp($dati_ca[$num_costo]['categoria'],"")) esegui_query("update $tablecostiprenota set categoria = '".$dati_ca[$num_costo]['categoria']."' where idcostiprenota = '$idcostiprenota'");
+} # fine if ($associa_costo == "SI")
+} # fine if ($associa_costo == "SI")
+} # fine if (!$dati_ca[$num_costo]['valore'] and !$dati_ca[$num_costo]['valore_perc'] and...
+} # fine for $num_costo
+} # fine if ($ins_costi_agg == "costi_nulli")
+
+
 if ($origine_prenota[$n_t] and $origini_prenota) {
 $orig_trovata = "NO";
 for ($num2 = 0 ; $num2 < count($origini_prenota) ; $num2++) {
