@@ -171,7 +171,7 @@ if ($ultimo_mese != $m_mostra) {
 if ($ultimo_mese) {
 $a_mostra = date("Y",mktime(0,0,0,$m_inizio_periodo,($g_inizio_periodo + $num2 -1),$a_inizio_periodo));
 $riga_mese .= "<td colspan=\"$num_col_mese\">$aper_font_tab_disp";
-if ($num_col_mese > 7) $riga_mese .= $nome_mese["$ultimo_mese"]."&nbsp;$a_mostra";
+if ($num_col_mese > 7) $riga_mese .= $nome_mese[$ultimo_mese]."&nbsp;$a_mostra";
 else $riga_mese .= "&nbsp;";
 $riga_mese .= "$chiu_font_tab_disp</td>";
 $num_col_mese = 0;
@@ -195,7 +195,7 @@ $riga_giorni .= ">$aper_font_tab_disp$g_mostra$chiu_font_tab_disp</td>";
 } # fine for $num1
 $a_mostra = date("Y",mktime(0,0,0,$m_inizio_periodo,($g_inizio_periodo + $num2 -1),$a_inizio_periodo));
 $riga_mese .= "<td colspan=\"$num_col_mese\">$aper_font_tab_disp";
-if ($num_col_mese > 6) $riga_mese .= $nome_mese["$ultimo_mese"]."&nbsp;$a_mostra";
+if ($num_col_mese > 6) $riga_mese .= $nome_mese[$ultimo_mese]."&nbsp;$a_mostra";
 else $riga_mese .= "&nbsp;";
 if ($colonna_destra_tab_disp != "NO") $riga_mese .= "$chiu_font_tab_disp</td><td rowspan=\"2\">$aper_font_tab_disp&nbsp;$chiu_font_tab_disp</td></tr>";
 else $riga_mese .= "$chiu_font_tab_disp</td></tr>";
