@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2009 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2015 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -86,8 +86,8 @@ $prima_data = explode($prima_data_vett[1],$prima_data);
 $prima_data = $prima_data[0];
 } # fine if ($prima_data_vett[1])
 $prima_data_corr = preg_split("|[-/ ]|",$prima_data);
-if (strlen($prima_data_corr[0] < 2)) $prima_data_corr[0] = "0".$prima_data_corr[0];
-if (strlen($prima_data_corr[1] < 2)) $prima_data_corr[1] = "0".$prima_data_corr[1];
+if (strlen($prima_data_corr[0]) < 2) $prima_data_corr[0] = "0".$prima_data_corr[0];
+if (strlen($prima_data_corr[1]) < 2) $prima_data_corr[1] = "0".$prima_data_corr[1];
 if ((integer) $prima_data_corr[0] > 12) $prima_data = $prima_data_corr[2]."-".$prima_data_corr[1]."-".$prima_data_corr[0];
 else {
 if ((integer) $prima_data_corr[1] > 12) $prima_data = $prima_data_corr[2]."-".$prima_data_corr[0]."-".$prima_data_corr[1];
@@ -110,8 +110,8 @@ $prima_data = explode($prima_data_vett[1],$prima_data);
 $prima_data = $prima_data[0];
 } # fine if ($prima_data_vett[1])
 $prima_data_corr = preg_split("|[-/ ]|",$prima_data);
-if (strlen($prima_data_corr[1] < 2)) $prima_data_corr[1] = "0".$prima_data_corr[1];
-if (strlen($prima_data_corr[2] < 2)) $prima_data_corr[2] = "0".$prima_data_corr[2];
+if (strlen($prima_data_corr[1]) < 2) $prima_data_corr[1] = "0".$prima_data_corr[1];
+if (strlen($prima_data_corr[2]) < 2) $prima_data_corr[2] = "0".$prima_data_corr[2];
 $prima_data = $prima_data_corr[0]."-".$prima_data_corr[1]."-".$prima_data_corr[2];
 } # fine if ($lung_prima_data_corr < $lung_prima_data)
 } # fine if (preg_match("|[^0-9][0-9]{4,4}[-/ ][0-9]{1,2}[-/ ][0-9]{1,2}[^0-9]|",$testo))
@@ -196,7 +196,7 @@ if ($prima_data_corr[1] == $Set or $prima_data_corr[1] == $Settembre) $mese = "0
 if ($prima_data_corr[1] == $Ott or $prima_data_corr[1] == $Ottobre) $mese = "10";
 if ($prima_data_corr[1] == $Nov or $prima_data_corr[1] == $Novembre) $mese = "11";
 if ($prima_data_corr[1] == $Dic or $prima_data_corr[1] == $Dicembre) $mese = "12";
-if (strlen($prima_data_corr[0] < 2)) $prima_data_corr[0] = "0".$prima_data_corr[0];
+if (strlen($prima_data_corr[0]) < 2) $prima_data_corr[0] = "0".$prima_data_corr[0];
 $prima_data = $prima_data_corr[2]."-".$mese."-".$prima_data_corr[0];
 } # fine if ($lung_prima_data_corr < $lung_prima_data)
 } # fine if (preg_match("=[^0-9a-z][0-9]{1,2}[, -/]+($mesi_alternativi)[, -/]+[0-9]{4,4}[^0-9a-z]=i",$testo))
