@@ -84,7 +84,7 @@ case "La tipologia è sbagliata":  		$messaggio = "The type is wrong"; break;
 case "è":  					$messaggio = "is"; break;
 case "pien":  					$messaggio = "full"; break;
 case "Non c'è più disponibilità nel periodo richiesto":	$messaggio = "There is not availability anymore in the requested period"; break;
-case "C'è ancora disponibilita":		$messaggio = "There is still availability"; break;
+case "C'è ancora disponibilità":		$messaggio = "There is still availability"; break;
 case "nel periodo richiesto":			$messaggio = "in the requested period"; break;
 case "nei periodi richiesti":			$messaggio = "in the requested periods"; break;
 case "per la tipologia":			$messaggio = "for type"; break;
@@ -273,7 +273,7 @@ case "Data di partenza":  			$messaggio = "Departure date"; break;
 case "Tipologia":  				$messaggio = "Type"; break;
 case "default - frame orizzontale":  		$messaggio = "default - horizontal frame"; break;
 case "Condizioni da accettare nella form":  	$messaggio = "Agreements to be accepted in the form"; break;
-case "nomi dall'utente delle liste, opzionali nel commento":	$messaggio = "names from lists user, optionals in comment"; break;
+case "nomi dall'utente delle liste":		$messaggio = "names from lists user"; break;
 case "Accetto":  				$messaggio = "I accept"; break;
 case "documento":  				$messaggio = "document"; break;
 case "larghezza":  				$messaggio = "width"; break;
@@ -290,6 +290,10 @@ case "Categoria":  				$messaggio = "Category"; break;
 case "Attenzione":  				$messaggio = "Warning"; break;
 case "le regole 1 di chiusura vengono sempre applicate":	$messaggio = "rules 1 for closure are always applied"; break;
 case "La tipologia richiesta è chiusa in questo periodo":	$messaggio = "The requested type is closed in this period"; break;
+case "Spostamento orizzontale della posizione":	$messaggio = "Horizontal offset for position"; break;
+case "aggiunto al commento":  			$messaggio = "added to comment"; break;
+case "aggiunto al campo":  			$messaggio = "added to field"; break;
+case "del cliente":  				$messaggio = "in client data"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
@@ -352,6 +356,7 @@ case "var_stile_riquadro_calendario":  		$messaggio = "var_calendar_box_style";
 case "var_stile_tabella_calendario":  		$messaggio = "var_calendar_table_style"; break;
 case "var_stile_bottoni_calendario":  		$messaggio = "var_calendar_buttons_style"; break;
 case "var_stile_bottone_apertura_calendario":  	$messaggio = "var_open_calendar_button_style"; break;
+case "var_spostamento_orizzontale_calendario":  $messaggio = "var_calendar_horizontal_offset"; break;
 case "var_colore_data_attiva_calendario":  	$messaggio = "var_color_active_calendar_date"; break;
 case "var_colore_data_selezionata_calendario":	$messaggio = "var_color_selected_calendar_date"; break;
 case "var_stile_tabella_prenotazione":  	$messaggio = "var_reservation_table_style"; break;
@@ -493,6 +498,7 @@ case "var_metodi_pagamento_da_chiedere":  	$messaggio = "var_payment_methods_to_
 case "var_nomi_metodi_pagamento_imposti":  	$messaggio = "var_imposed_payment_methods_names"; break;
 case "var_campi_form_personalizzati":  		$messaggio = "var_custom_form_fields"; break;
 case "var_chiedi_campi_form_personalizzati":  	$messaggio = "var_ask_custom_form_fields"; break;
+case "var_ins_campi_form_personalizzati":  	$messaggio = "var_ins_custom_form_fields"; break;
 case "var_campi_form_doc_condizioni":  		$messaggio = "var_doc_conditions_form_fields"; break;
 case "var_chiedi_campi_form_doc_condizioni":  	$messaggio = "var_ask_doc_conditions_form_fields"; break;
 case "var_fr_Cognome":  			$messaggio = "var_phr_Surname"; break;
