@@ -89,7 +89,7 @@ case "Il formato dell'anno richiesto è sbagliato":	$messaggio = "The format of
 case "I mesi erano indicati erroneamente, sono stati inseriti i mesi da Gennaio a Dicembre":	$messaggio = "Months were wrongly selected, they have been inserted from January to December"; break;
 case "N&deg;":  				$messaggio = "N&deg;"; break;
 case "Cognome del cliente":  			$messaggio = "Client surname"; break;
-case "Data iniziale":  				$messaggio = "Strarting date"; break;
+case "Data iniziale":  				$messaggio = "Starting date"; break;
 case "Data finale":  				$messaggio = "Ending date"; break;
 case "Tariffa completa":  			$messaggio = "Complete rate"; break;
 case "Da pagare":  				$messaggio = "To pay"; break;
