@@ -117,9 +117,9 @@ $lista_nazioni[53] = "Cambodia";
 $cod2_nazioni[53] = "KH";
 $lista_nazioni[54] = "China";
 $cod2_nazioni[54] = "CN";
-$lista_nazioni[55] = "South Corea";
+$lista_nazioni[55] = "South Korea";
 $cod2_nazioni[55] = "KR";
-$lista_nazioni[56] = "North Corea";
+$lista_nazioni[56] = "North Korea";
 $cod2_nazioni[56] = "KP";
 $lista_nazioni[57] = "United Arab Emirates";
 $cod2_nazioni[57] = "AE";
