@@ -41,6 +41,7 @@ case "non riuscita!":  				$messaggio = "was refused!"; break;
 case "Controllare i dati immessi in \"configura e personalizza\"":	$messaggio = "Check data inserted in \"configure and customize\""; break;
 case "Dati ricavati dal messaggio email":  	$messaggio = "Data extracted from email message"; break;
 case "Controlla disponibilità":  		$messaggio = "Check availability"; break;
+case "Modifica":  				$messaggio = "Modify"; break;
 case "Nome":  					$messaggio = "Name"; break;
 case "Email":  					$messaggio = "Email"; break;
 case "arrivo":  				$messaggio = "arrival"; break;
@@ -52,7 +53,8 @@ case "ospiti":  				$messaggio = "guests"; break;
 case "adulti":  				$messaggio = "adults"; break;
 case "bambini":  				$messaggio = "children"; break;
 case "gruppo":  				$messaggio = "party"; break;
-case "Modifica":  				$messaggio = "Modify"; break;
+case "date":  					$messaggio = "dates"; break;
+case "viaggiatori":  				$messaggio = "travelers"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
