@@ -128,10 +128,10 @@ case "il numero di carta di credito è <span class=\"colred\">sbagliato</span>":
 case "il numero CVC è <span class=\"colred\">sbagliato</span>":	$messaggio = "CVC number is <span class=\"colred\">wrong</span>"; break;
 case "i dati della carta di credito sono stati inseriti":	$messaggio = "credit card data have been inserted"; break;
 case "carta di credito del cliente":  		$messaggio = "credit card of client"; break;
-case "tipo":  					$messaggio = "type"; break;
-case "numero":  				$messaggio = "number"; break;
-case "titolare":  				$messaggio = "titular"; break;
-case "scadenza":  				$messaggio = "expiration"; break;
+case "Tipo":  					$messaggio = "Type"; break;
+case "Numero":  				$messaggio = "Number"; break;
+case "Titolare":  				$messaggio = "Holder"; break;
+case "Scadenza":  				$messaggio = "Expiration"; break;
 case "CVC":  					$messaggio = "CVC"; break;
 case "modifica i dati della carta di credito":	$messaggio = "modify credit card data"; break;
 case "cancella questa carta di credito":  	$messaggio = "delete this credit card"; break;
