@@ -82,6 +82,10 @@ case "Chiusura html cambiata":  		$messaggio = "Html foot changed"; break;
 case "Incrementa il numero progressivo ad ogni sua apparizione":	$messaggio = "Increase the progressive number each time that it appears"; break;
 case "Ogni documento avrà un unico numero progressivo":	$messaggio = "Each document will have a unique progressive number"; break;
 case "Il numero progressivo verrà incrementato ogni volta che compare nel documento":	$messaggio = "The progressive number will be increased each time it appears in the document"; break;
+case "Estensione con cui vedere e scaricare il documento":	$messaggio = "Extension for viewing and downloading the document"; break;
+case "predefinita":  				$messaggio = "default"; break;
+case "personalizzata":  			$messaggio = "custom"; break;
+case "Estensione cambiata":  			$messaggio = "Extension changed"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
