@@ -24,7 +24,7 @@ case "arrotondato a":  				$messaggio = "rounded to"; break;
 case "Utilizzare una variabile personalizzata che finisce con \"_p\" per aggiungervi i separatori delle migliaia e 2 decimali dopo l'operazione":	$messaggio = "Use a custom variable that ends with \"_p\" to add the thousands separators and 2 decimals after the operation"; break;
 case "e":  					$messaggio = "and"; break;
 case "o":  					$messaggio = "or"; break;
-case "concatenato con":  				$messaggio = "concatenated with"; break;
+case "concatenato con":  			$messaggio = "concatenated with"; break;
 case "allora":  				$messaggio = "then"; break;
 case "uguaglia":  				$messaggio = "equate"; break;
 case "concatena":  				$messaggio = "concatenate"; break;
@@ -43,6 +43,7 @@ case "Array della variabile":  			$messaggio = "Array of variable"; break;
 case "Valori iniziali da assegnare all'array":	$messaggio = "Initial values to be assigned to the array"; break;
 case "Nessun valore predefinito":  		$messaggio = "No initial values"; break;
 case "valori progressivi tra le date selezionate":	$messaggio = "progressive values between selected dates"; break;
+case "valori progressivi tra il primo arrivo e l'ultima partenza":	$messaggio = "progressive values between first arrival and last departure"; break;
 case "una lista di valori predefiniti":  	$messaggio = "a list of predefined values"; break;
 case "separati da virgole":  			$messaggio = "comma separated"; break;
 case "nelle ripetizioni vengono considerate solo le prenotazioni nella data valutata":	$messaggio = "in repetitions only reservations in evaluated date are considered"; break;
@@ -99,6 +100,10 @@ case "mesi":  					$messaggio = "months"; break;
 case "anni":  					$messaggio = "years"; break;
 case "i valori dell'array":  			$messaggio = "the values from array"; break;
 case "elimina questo &quot;se&quot;":  		$messaggio = "delete this &quot;if&quot;"; break;
+case "uguale al numero di":  			$messaggio = "equal to the number of"; break;
+case "numero di":  				$messaggio = "the number of"; break;
+case "dalla data":  				$messaggio = "from date"; break;
+case "alla data":  				$messaggio = "to date"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
