@@ -374,6 +374,29 @@ case "tipo":  					$messaggio = "type"; break;
 case "booleano":  				$messaggio = "boolean"; break;
 case "testo":  					$messaggio = "text"; break;
 case "Il campo personalizzato contiene caratteri non consentiti":	$messaggio = "The custom field contains not allowed characters"; break;
+case "Gestire anche i codici CVC delle carte di credito":	$messaggio = "Manage the CVC codes from credit cards too"; break;
+case "Esonero di responsabilità":  		$messaggio = "Disclaimer"; break;
+case "la gestione dei codici CVC avverrà sotto la propria responsabilità, essendo a conoscenza che gli standard di sicurezza PCI ne vietano la registrazione":	$messaggio = "the CVC codes will be managed under your own responsibility, being aware that PCI security standards forbid their storage"; break;
+case "L'accettazione di questa clausola conferma che gli sviluppatori di questo software sono liberi da ogni responsibilità sulla sicurezza di questi dati":	$messaggio = "Accepting this clause confirms that the developers of this software are free from all responsibilities regarding the security of these data"; break;
+case "Accetto":  				$messaggio = "I Accept"; break;
+case "Declino":  				$messaggio = "I Decline"; break;
+case "La gestione dei codici cvc è stata cambiata":	$messaggio = "The management of CVC codes has been changed"; break;
+case "Scegli le righe con i totali da mostrare":	$messaggio = "Choose which totals to show in rows"; break;
+case "giornaliero":  				$messaggio = "daily"; break;
+case "mensile":  				$messaggio = "montly"; break;
+case "tabella":  				$messaggio = "table"; break;
+case "Le righe da mostrare nelle tabelle delle casse sono state cambiate":	$messaggio = "Rows shown in cashobxes tables have been changed"; break;
+case "partenze e prenotazioni correnti":  	$messaggio = "departures and current reservations"; break;
+case "Commenti personalizzati delle prenotazioni":	$messaggio = "Custom comments for reservations"; break;
+case "Commento personalizzato della prenotazione eliminato":	$messaggio = "Custom comment for reservation deleted"; break;
+case "Nuovo commento personalizzato della prenotazione aggiunto":	$messaggio = "New custom comment for reservation added"; break;
+case "Punto vendita ed inventario":  		$messaggio = "Point of sale and inventory"; break;
+case "Ordinamento nell'inventario e punto vendita":	$messaggio = "Sorting in inventory and point of sale"; break;
+case "alfabetico":  				$messaggio = "alphabetically"; break;
+case "per ordine di inserimento":  		$messaggio = "by insertion order"; break;
+case "Tasti per operazioni nel punto vendita":	$messaggio = "Buttons for operations in point of sale"; break;
+case "L'ordinamento nell'inventario e nel punto vendita è stato cambiato":	$messaggio = "Sorting in inventory and point of sale has been changed"; break;
+case "I tasti per operazioni nel punto vendita sono stati cambiati":	$messaggio = "Buttons for operations in point of sale have been changed"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
