@@ -48,7 +48,8 @@ case "Possibilità di confermare la prenotazione":	$messaggio = "Possibility to
 case "Possibilità di inserire uno sconto":  	$messaggio = "Possibility to insert a discount"; break;
 case "Possibilità di inserire la caparra e le commissioni":	$messaggio = "Possibility to insert deposit and commissions"; break;
 case "Possibilità di inserire dei costi aggiuntivi":	$messaggio = "Possibility to insert extra costs"; break;
-case "Possibilità di inserire un commento":  	$messaggio = "Possibility to insert a comment"; break;
+case "Possibilità di inserire il commento":  	$messaggio = "Possibility to insert the comment"; break;
+case "Possibilità di inserire i commenti personalizzati":	$messaggio = "Possibility to insert custom comments"; break;
 case "Possibilità di inserire il numero di persone":	$messaggio = "Possibility to insert the number of people"; break;
 case "Possibilità di inserire prenotazioni anche in periodi già iniziati":	$messaggio = "Possibility to insert reservations also in periods already begun"; break;
 case "Prenotazioni che possono essere <i>modificate</i>":	$messaggio = "Reservations that can be <i>modified</i>"; break;
@@ -61,7 +62,9 @@ case "Possibilità di modificare la tariffa":  	$messaggio = "Possibility to mod
 case "Si, con regola 2 a scelta":  		$messaggio = "Yes, with rule 2 at will"; break;
 case "Si, sempre con regola 2":  		$messaggio = "Yes, always with rule 2"; break;
 case "Possibilità di modificare il numero delle persone":	$messaggio = "Possibility to modify the number of people"; break;
+case "Possibilità di vedere il commento":  	$messaggio = "Possibility to view the comment"; break;
 case "Possibilità di modificare il commento":  	$messaggio = "Possibility to modify the comment"; break;
+case "Possibilità di vedere e modificare i commenti personalizzati":	$messaggio = "Possibility to view and modify custom comments"; break;
 case "Possibilità di modificare lo sconto":  	$messaggio = "Possibility to modify the discount"; break;
 case "Possibilità di modificare la caparra e le commissioni":  	$messaggio = "Possibility to modify deposit and commissions"; break;
 case "Possibilità di modificare i costi aggiuntivi":	$messaggio = "Possibility to modify extra costs"; break;
@@ -145,8 +148,10 @@ case "non potrà inserire la <b>caparra</b> e le <b>commissioni</b> quando inser
 case "potrà inserire la <b>caparra</b> e le <b>commissioni</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will be able to insert the <b>deposit</b> and the <b>commissions</b> when he inserts new reservations in"; break;
 case "non potrà inserire dei <b>costi aggiuntivi</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will not be able to insert <b>extra costs</b> when inserts new reservations in"; break;
 case "potrà inserire dei <b>costi aggiuntivi</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will be able to insert <b>extra costs</b> when inserts new reservations in"; break;
-case "non potrà inserire dei <b>commenti</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will not be able to insert <b>comments</b> when inserts new reservations in"; break;
-case "potrà inserire dei <b>commenti</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will be able to insert <b>comments</b> when inserts new reservations in"; break;
+case "non potrà inserire il <b>commento</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will not be able to insert the <b>comment</b> when inserts new reservations in"; break;
+case "potrà inserire il <b>commento</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will be able to insert the <b>comment</b> when inserts new reservations in"; break;
+case "non potrà inserire i <b>commenti personalizzati</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will not be able to insert <b>custom comments</b> when inserts new reservations in"; break;
+case "potrà inserire i <b>commenti personalizzati</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will be able to insert <b>custom comments</b> when inserts new reservations in"; break;
 case "non potrà inserire il <b>numero delle persone</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will not be able to insert the <b>number of people</b> when he inserts new reservations in"; break;
 case "potrà inserire il <b>numero delle persone</b> quando inserisce nuove prenotazioni nel":	$messaggio = "will be able to insert the <b>number of people</b> when he inserts new reservations in"; break;
 case "non potrà inserire nuove prenotazioni in <b>periodi già iniziati</b> nel":	$messaggio = "will not be able to insert new reservations in <b>already begun periods</b> in"; break;
@@ -161,8 +166,12 @@ case "non potrà modificare la <b>tariffa</b> delle prenotazioni nel":	$messaggi
 case "potrà modificare la <b>tariffa</b> delle prenotazioni, scegliendo se utilizzare la regola 2, nel":	$messaggio = "will be able to modify the <b>rate</b> of reservations, choosing if use rule 2, in"; break;
 case "non potrà modificare il <b>numero delle persone</b> delle prenotazioni nel":	$messaggio = "will not be able to modify the <b>number of people</b> of reservations in"; break;
 case "potrà modificare il <b>numero delle persone</b> delle prenotazioni nel":	$messaggio = "will be able to modify the <b>number of people</b> of reservations in"; break;
+case "non potrà vedere il <b>commento</b> delle prenotazioni nel":	$messaggio = "will not be able to view the <b>comment</b> of reservations in"; break;
+case "potrà vedere il <b>commento</b> delle prenotazioni nel":	$messaggio = "will be able to view the <b>comment</b> of reservations in"; break;
 case "non potrà modificare il <b>commento</b> delle prenotazioni nel":	$messaggio = "will not be able to modify the <b>comment</b> of reservations in"; break;
 case "potrà modificare il <b>commento</b> delle prenotazioni nel":	$messaggio = "will be able to modify the <b>comment</b> of reservations in"; break;
+case "non potrà vedere e modificare i <b>commenti personalizzati</b> delle prenotazioni nel":	$messaggio = "will not be able to view and modify <b>custom comments</b> of reservations in"; break;
+case "potrà vedere e modificare i <b>commenti personalizzati</b> delle prenotazioni nel":	$messaggio = "will be able to view and modify <b>custom comments</b> of reservations in"; break;
 case "non potrà modificare lo <b>sconto</b> delle prenotazioni nel":	$messaggio = "will not be able to modify the <b>discount</b> of reservations in"; break;
 case "potrà modificare lo <b>sconto</b> delle prenotazioni nel":	$messaggio = "will be able to modify the <b>discount</b> of reservations in"; break;
 case "non potrà modificare la <b>caparra</b> e le <b>commissioni</b> delle prenotazioni nel":	$messaggio = "will not be able to modify the <b>deposit</b> and the <b>commissions</b> of reservations in"; break;
@@ -329,6 +338,12 @@ case "solo correnti e future":  		$messaggio = "only current and future"; break;
 case "vedrà le prenotazioni non permesse come <em>oscurate</em>":	$messaggio = "will see not permitted reservations as <em>obscured</em>"; break;
 case "vedrà le prenotazioni non permesse come <em>periodi vuoti</em>":	$messaggio = "will see not permitted reservations as <em>empty periods</em>"; break;
 case "vedrà le prenotazioni non permesse come <em>periodi vuoti nel passato ed oscurate nel presente e nel futuro</em>":	$messaggio = "will see not permitted reservations as <em>empty periods in the past, obscured in the present and future</em>"; break;
+case "Possibilità di cancellare o sovrascrivere i documenti salvati":	$messaggio = "Possibility to delete and overwrite saved documents"; break;
+case "potrà <b>cancellare e sovrascrivere i documenti</b> salvati nel":	$messaggio = "will be able to <b>delete and overwrite documents</b> saved in"; break;
+case "non potrà <b>cancellare e sovrascrivere i documenti</b> salvati nel":	$messaggio = "will not be able to <b>delete and overwrite documents</b> saved in"; break;
+case "Creazione e modifica delle interconnessioni":	$messaggio = "Create and modify interconnections"; break;
+case "potrà creare e modificare le <b>interconnessioni</b>":	$messaggio = "will be able to create and modify <b>interconnections</b>"; break;
+case "non potrà più creare e modificare le <b>interconnessioni</b>":	$messaggio = "will not be able to create and modify <b>interconnections</b>"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
