@@ -209,7 +209,7 @@ case "OK":  					$messaggio = "OK"; break;
 case "Annulla":  				$messaggio = "Cancel"; break;
 case "Si è sicuri di voler <div style=\"display: inline; color: red;\"><b>cancellare":	$messaggio = "Are you sure you want to <div style=\"display: inline; color: red;\"><b>delete"; break;
 case "clienti</b></div> che non sono associati a nessuna prenotazione e nessun pagamento":	$messaggio = "clients</b></div> that don't have any associated reservation or payment"; break;
-case "carte di credito</b></div> associate a clienti che non hanno nessuna prenotazione nel futuro":	$messaggio = "credit cards</b></div> from clients without reservations in the future"; break;
+case "carte di credito</b></div> associate a clienti che non hanno nessuna prenotazione nel futuro e nessuna prenotazione non pagata":	$messaggio = "credit cards</b></div> from clients without reservations in the future and without unpaid reservations"; break;
 case "Cancella i clienti senza prenotazioni":	$messaggio = "Delete clients without reservations"; break;
 case "Metodo pagamento":  			$messaggio = "Payment method"; break;
 case "Tariffe":  				$messaggio = "Rates"; break;
@@ -354,6 +354,9 @@ case "Creare":  				$messaggio = "Create"; break;
 case "Aggiungi":  				$messaggio = "Add"; break;
 case "persona":  				$messaggio = "person"; break;
 case "chiusa":  				$messaggio = "closed"; break;
+case "presenti in data":  			$messaggio = "present on"; break;
+case "comprese partenze":  			$messaggio = "including departures"; break;
+case "escludere_da_totale_percentuale":  	$messaggio = "exclude_from_percentage_total"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
