@@ -34,12 +34,12 @@ case "Esistono i seguenti clienti con un cognome e nome uguale o simile":	$messa
 case "nato il":	  				$messaggio = "nacido el"; break;
 case "nata il":	  				$messaggio = "nacida el"; break;
 case "CAP":  					$messaggio = "codigo postal"; break;
-case "Telefono":  				$messaggio = "Telefono"; break;
-case "2º telefono":  				$messaggio = "2º telefono"; break;
-case "3º telefono":  				$messaggio = "3º telefono"; break;
+case "Telefono":  				$messaggio = "Teléfono"; break;
+case "2º telefono":  				$messaggio = "2º teléfono"; break;
+case "3º telefono":  				$messaggio = "3º teléfono"; break;
 case "Utilizza il cliente":  			$messaggio = "Utiliza el cliente"; break;
 case "per la prenotazione":  			$messaggio = "para la reserva"; break;
-case "Modifica i dati del cliente":  		$messaggio = "Modifica los datos del cliente"; break;
+case "Modifica i dati del cliente":  		$messaggio = "Modificar los datos del cliente"; break;
 case "Inserisci un nuovo cliente":  		$messaggio = "Inserta un nuevo cliente"; break;
 case "É necessario inserire il cognome del cliente":	$messaggio = "Hay que insertar el apellido del cliente"; break;
 case "I dati del cliente":  			$messaggio = "Los datos del cliente"; break;
@@ -57,22 +57,22 @@ case "Piazza":  				$messaggio = "Plaza"; break;
 case "Viale":  					$messaggio = "Avenida"; break;
 case "Piazzale":  				$messaggio = "Paseo"; break;
 case "Vicolo":  				$messaggio = "Bulevard"; break;
-case "Numero di telefono":  			$messaggio = "Número de telefono"; break;
-case "Secondo telefono":  			$messaggio = "Seguno telefono"; break;
-case "Terzo telefono":  			$messaggio = "Tercer telefono"; break;
+case "Numero di telefono":  			$messaggio = "Número de teléfono"; break;
+case "Secondo telefono":  			$messaggio = "Seguno teléfono"; break;
+case "Terzo telefono":  			$messaggio = "Tercer teléfono"; break;
 case "Numero di fax":  				$messaggio = "Número de fax"; break;
 case "Seconda persona di riferimento":  	$messaggio = "Segunda persona de referencia"; break;
 case "Inserisci i dati":  			$messaggio = "Inserta los datos"; break;
-case "Torna al menù principale":  		$messaggio = "Vuelve al menú principal"; break;
+case "Torna al menù principale":  		$messaggio = "Volver al menú principal"; break;
 case "Italia":  				$messaggio = ""; break;
 case "non verrano modificati i dati specifici delle 2 persone di riferimento":	$messaggio = "no serán modificados los datos específicos de las 2 personas de referencia"; break;
 case "sono stati modificati":  			$messaggio = "han sido modificados"; break;
 case "e":  					$messaggio = "y"; break;
-case "Il numero di prenotazioni è sbagliato":	$messaggio = "El numero de reservas está equivocado"; break;
+case "Il numero di prenotazioni è sbagliato":	$messaggio = "El número de reservas está equivocado"; break;
 case "Aggiungi":  				$messaggio = "Añade"; break;
 case "Nº di tipologie da aggiungere":  		$messaggio = "Nº de tipologías a añadir"; break;
 case "Non si è trovato nessun cliente chiamato":	$messaggio = "No se ha encontrado ningún cliente llamado"; break;
-case "Non c'è nussun periodo delle regole 1 in cui sia consentito inserire prenotazioni per l'utente":	$messaggio = "No hay ningun período de las reglas 1 en el que esté consentido insertar reservas para el usuario"; break;
+case "Non c'è nussun periodo delle regole 1 in cui sia consentito inserire prenotazioni per l'utente":	$messaggio = "No hay ningún período de las reglas 1 en el que esté consentido insertar reservas para el usuario"; break;
 case "Il numero di persone è sbagliato":  	$messaggio = "El número de personas está equivocado"; break;
 case "I dati di un costo aggiuntivo sono errati":	$messaggio = "Los datos de un coste añadido están equivocados"; break;
 case "Non si può inserire più di un costo aggiuntivo con percentuale sul prezzo totale per prenotazione":	$messaggio = "No se puede insertar mas de un coste añadido con percentual sobre el precio total por reserva"; break;
@@ -126,6 +126,7 @@ case "lingua":  				$messaggio = "idioma"; break;
 case "ln.":  					$messaggio = "id."; break;
 case "non può essere moltiplicato per più di":	$messaggio = "no puede ser multiplicado por más de"; break;
 case "La tariffa richiesta è chiusa in questo periodo":	$messaggio = "La tarifa seleccionada está cerrada en este período"; break;
+case "Commento":  				$messaggio = "Comentario"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
