@@ -84,7 +84,7 @@ case "La tipologia è sbagliata":  		$messaggio = "La tipología está equivocad
 case "è":  					$messaggio = "está"; break;
 case "pien":  					$messaggio = "llen"; break;
 case "Non c'è più disponibilità nel periodo richiesto":	$messaggio = "Ya no hay más disponibilidad en el período pedido"; break;
-case "C'è ancora disponibilita":		$messaggio = "Todavía hay disponibilidad"; break;
+case "C'è ancora disponibilità":		$messaggio = "Todavía hay disponibilidad"; break;
 case "nel periodo richiesto":			$messaggio = "en el período pedido"; break;
 case "nei periodi richiesti":			$messaggio = "en los períodos pedidos"; break;
 case "per la tipologia":			$messaggio = "para la tipología"; break;
@@ -273,7 +273,7 @@ case "Data di partenza":  			$messaggio = "Fecha de salida"; break;
 case "Tipologia":  				$messaggio = "Tipologia"; break;
 case "default - frame orizzontale":  		$messaggio = "default - frame horizontál"; break;
 case "Condizioni da accettare nella form":  	$messaggio = "Condiciónes a aceptar en el formulario"; break;
-case "nomi dall'utente delle liste, opzionali nel commento":	$messaggio = "nombres del usuario de las listas, opcionales en el comentario"; break;
+case "nomi dall'utente delle liste":		$messaggio = "nombres del usuario de las listas"; break;
 case "Accetto":  				$messaggio = "Acepto"; break;
 case "documento":  				$messaggio = "documento"; break;
 case "larghezza":  				$messaggio = "anchura"; break;
@@ -290,6 +290,10 @@ case "Categoria":  				$messaggio = "Categoría"; break;
 case "Attenzione":  				$messaggio = "Atención"; break;
 case "le regole 1 di chiusura vengono sempre applicate":	$messaggio = "las reglas 1 de cierre son aplicadas siempre"; break;
 case "La tipologia richiesta è chiusa in questo periodo":	$messaggio = "La tipología pedida está cerrada en este período"; break;
+case "Spostamento orizzontale della posizione":	$messaggio = "Desplazamiento horizontal de la posición"; break;
+case "aggiunto al commento":  			$messaggio = "añadido al comentario"; break;
+case "aggiunto al campo":  			$messaggio = "añadido al campo"; break;
+case "del cliente":  				$messaggio = "del cliente"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
@@ -352,6 +356,7 @@ case "var_stile_riquadro_calendario":  		$messaggio = "var_estilo_recuadro_calen
 case "var_stile_tabella_calendario":  		$messaggio = "var_estilo_tabla_calendario"; break;
 case "var_stile_bottoni_calendario":  		$messaggio = "var_estilo_botones_calendario"; break;
 case "var_stile_bottone_apertura_calendario":  	$messaggio = "var_estilo_boton_apertura_calendario"; break;
+case "var_spostamento_orizzontale_calendario":  $messaggio = "var_desplazamiento_horizontal_calendario"; break;
 case "var_colore_data_attiva_calendario":  	$messaggio = "var_color_fecha_activa_calendario"; break;
 case "var_colore_data_selezionata_calendario":	$messaggio = "var_color_fecha_seleccionada_calendario"; break;
 case "var_stile_tabella_prenotazione":  	$messaggio = "var_estilo_tabla_reserva"; break;
@@ -493,6 +498,7 @@ case "var_metodi_pagamento_da_chiedere":  	$messaggio = "var_metodos_pago_a_pedi
 case "var_nomi_metodi_pagamento_imposti":  	$messaggio = "var_nombres_metodos_pago_impuestos"; break;
 case "var_campi_form_personalizzati":  		$messaggio = "var_campos_formulario_personalizados"; break;
 case "var_chiedi_campi_form_personalizzati":  	$messaggio = "var_pedir_campos_formulario_personalizados"; break;
+case "var_ins_campi_form_personalizzati":  	$messaggio = "var_ins_campos_formulario_personalizados"; break;
 case "var_campi_form_doc_condizioni":  		$messaggio = "var_campos_formulario_doc_condiciones"; break;
 case "var_chiedi_campi_form_doc_condizioni":  	$messaggio = "var_pedir_campos_formulario_doc_condiciones"; break;
 case "var_fr_Cognome":  			$messaggio = "var_fr_Apellido"; break;
