@@ -41,6 +41,7 @@ case "non riuscita!":  				$messaggio = "ha sido rechazada!"; break;
 case "Controllare i dati immessi in \"configura e personalizza\"":	$messaggio = "Controlar los datos insertados en \"configurar y personalizar\""; break;
 case "Dati ricavati dal messaggio email":  	$messaggio = "Datos extraídos del mensaje email"; break;
 case "Controlla disponibilità":  		$messaggio = "Controlar disponibilidad"; break;
+case "Modifica":  				$messaggio = "Modificar"; break;
 case "Nome":  					$messaggio = "Nombre"; break;
 case "Email":  					$messaggio = "Email"; break;
 case "arrivo":  				$messaggio = "llegada"; break;
@@ -52,7 +53,8 @@ case "ospiti":  				$messaggio = "huéspedes"; break;
 case "adulti":  				$messaggio = "adultos"; break;
 case "bambini":  				$messaggio = "niños"; break;
 case "gruppo":  				$messaggio = "grupo"; break;
-case "Modifica":  				$messaggio = "Modificar"; break;
+case "date":  					$messaggio = "fechas"; break;
+case "viaggiatori":  				$messaggio = "viajeros"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
