@@ -130,10 +130,10 @@ case "il numero di carta di credito è <span class=\"colred\">sbagliato</span>":
 case "il numero CVC è <span class=\"colred\">sbagliato</span>":	$messaggio = "el número de CVC está <span class=\"colred\">equivocado</span>"; break;
 case "i dati della carta di credito sono stati inseriti":	$messaggio = "los datos de la tarjeta de crédito han sido insertados"; break;
 case "carta di credito del cliente":  		$messaggio = "tarjeta de crédito del cliente"; break;
-case "tipo":  					$messaggio = "tipo"; break;
-case "numero":  				$messaggio = "número"; break;
-case "titolare":  				$messaggio = "titular"; break;
-case "scadenza":  				$messaggio = "expiración"; break;
+case "Tipo":  					$messaggio = "Tipo"; break;
+case "Numero":  				$messaggio = "Número"; break;
+case "Titolare":  				$messaggio = "Titular"; break;
+case "Scadenza":  				$messaggio = "Expiración"; break;
 case "CVC":  					$messaggio = "CVC"; break;
 case "modifica i dati della carta di credito":	$messaggio = "modificar los datos de la tarjeta de crédito"; break;
 case "cancella questa carta di credito":  	$messaggio = "borrar esta tarjeta de crédito"; break;
