@@ -82,6 +82,10 @@ case "Chiusura html cambiata":  		$messaggio = "Cierre html cambiado"; break;
 case "Incrementa il numero progressivo ad ogni sua apparizione":	$messaggio = "Incrementar el número progresivo cada vez que aparece"; break;
 case "Ogni documento avrà un unico numero progressivo":	$messaggio = "Cada documento tendrá un único número progresivo"; break;
 case "Il numero progressivo verrà incrementato ogni volta che compare nel documento":	$messaggio = "El número progresivo será incrementado daca vez que aparezca en el documento"; break;
+case "Estensione con cui vedere e scaricare il documento":	$messaggio = "Extensión para ver y descargar el documento"; break;
+case "predefinita":  				$messaggio = "predefinida"; break;
+case "personalizzata":  			$messaggio = "personalizada"; break;
+case "Estensione cambiata":  			$messaggio = "Extensión cambiada"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
