@@ -2,7 +2,7 @@
 
 switch ($messaggio) {
 
-case "Modifica o cancella la prenotazione":	$messaggio = "Modifica o borra la reserva"; break;
+case "Modifica o cancella la prenotazione":	$messaggio = "Modificar o borrar la reserva"; break;
 case "Prenotazione a nome di":  		$messaggio = "Reserva a nombre de"; break;
 case "nato il":  				$messaggio = "nacido el"; break;
 case "nata il":  				$messaggio = "nacida el"; break;
@@ -11,13 +11,13 @@ case "CAP":  					$messaggio = "código postal"; break;
 case "Telefono":  				$messaggio = "Teléfono"; break;
 case "2º telefono":  				$messaggio = "2° teléfono"; break;
 case "3º telefono":  				$messaggio = "3er teléfono"; break;
-case "Modifica i dati del cliente":  		$messaggio = "Modifica los datos del cliente"; break;
+case "Modifica i dati del cliente":  		$messaggio = "Modificar los datos del cliente"; break;
 case "La prenotazione è dell'anno precedente, si potrà modificare solo la data finale":	$messaggio = "La reserva es del año anterior, se podrá modificar solo la fecha final"; break;
 case "settimane":  				$messaggio = "semanas"; break;
 case "giorni":  				$messaggio = "días"; break;
 case "dal":  					$messaggio = "desde"; break;
 case "al":  					$messaggio = "hasta"; break;
-case "cambia in":  				$messaggio = "cambia a"; break;
+case "cambia in":  				$messaggio = "cambiar a"; break;
 case "in":  					$messaggio = "en"; break;
 case "Nº di piano":  				$messaggio = "N° de piso"; break;
 case "e/o di casa":  				$messaggio = "y/o de casa"; break;
@@ -56,7 +56,7 @@ case "Nuovo costo aggiuntivo giornaliero":  	$messaggio = "Nuevo coste añadido
 case "nº di settimane da applicare":  		$messaggio = "n° de samanas a aplicar"; break;
 case "nº di giorni da applicare":  		$messaggio = "n° de días a aplicar"; break;
 case "non specificato":  			$messaggio = "no especificado"; break;
-case "Modifica la prenotazione":  		$messaggio = "Modifica la reserva"; break;
+case "Modifica la prenotazione":  		$messaggio = "Modificar la reserva"; break;
 case "Cancella la prenotazione":  		$messaggio = "Borra la reserva"; break;
 case "documento di tipo":  			$messaggio = "documento tipo"; break;
 case "visualizza":  				$messaggio = "ver"; break;
@@ -186,7 +186,7 @@ case "considerate fisse perchè <div style=\"display: inline; color: red;\">ad o
 case "è incompatibile con la tariffa selezionata":	$messaggio = "es incompatible con la tarifa seleccionada"; break;
 case "non può essere applicato":  		$messaggio = "no puede ser aplicado"; break;
 case "Non si può cambiare l'assegnazione di una prenotazione che si trova <div style=\"display: inline; color: red;\">tra due anni</div>":	$messaggio = "No se puede cambiar la asignación de una reserva que se encuentra <div style=\"display: inline; color: red;\">entre dos años</div>"; break;
-case "Modifica nell'anno precedente":  		$messaggio = "Modifica en el año anterior"; break;
+case "Modifica nell'anno precedente":  		$messaggio = "Modificar en el año anterior"; break;
 case "Orario entrata stimato":  		$messaggio = "Horario entrada estimativo"; break;
 case "L'orario stimato di entrata verrà cambiato a":	$messaggio = "El horario de entrada estimativo será cambiado a"; break;
 case "Codice prenotazione":  			$messaggio = "Código reserva"; break;
@@ -204,7 +204,7 @@ case "numero":  				$messaggio = "número"; break;
 case "La prenotazione numero":  		$messaggio = "La reserva número"; break;
 case "non esiste":  				$messaggio = "no existe"; break;
 case "Ospiti della prenotazione":  		$messaggio = "Huéspedes de la reserva"; break;
-case "Modifica gli ospiti":  			$messaggio = "Modifica los huéspedes"; break;
+case "Modifica gli ospiti":  			$messaggio = "Modificar los huéspedes"; break;
 case "nato":  					$messaggio = "nacido"; break;
 case "nata":  					$messaggio = "nacida"; break;
 case "il":  					$messaggio = "el"; break;
@@ -213,8 +213,8 @@ case "scade":  					$messaggio = "caduca"; break;
 case "Codice fiscale":  			$messaggio = "N.I.F."; break;
 case "Origine":  				$messaggio = "Origen"; break;
 case "L'origine della prenotazione verrà cambiata a":	$messaggio = "El origen de la reserva será cambiado a"; break;
-case "Modifica o cancella le prenotazioni":  	$messaggio = "Modifica o borra las reservas"; break;
-case "Modifica le prenotazioni":  		$messaggio = "Modifica las reservas"; break;
+case "Modifica o cancella le prenotazioni":  	$messaggio = "Modificar o borrar las reservas"; break;
+case "Modifica le prenotazioni":  		$messaggio = "Modificar las reservas"; break;
 case "Cancella le prenotazioni":  		$messaggio = "Borra las reservas"; break;
 case "della prenotazione":  			$messaggio = "de la reserva"; break;
 case "per la prenotazione":  			$messaggio = "para la reserva"; break;
@@ -249,6 +249,9 @@ case "Verrà aggiunto un <b>promemoria</b> per l'<em>entrata</em>":	$messaggio =
 case "Verrà aggiunto un <b>promemoria</b> per l'<em>uscita</em>":	$messaggio = "Se añadirá un <b>recodatorio</b> para la <em>salida</em>"; break;
 case "Promemoria":  				$messaggio = "Recordatorio"; break;
 case "La <b>tariffa</b> richiesta è <span class=\"colred\">chiusa</span> in questo periodo":	$messaggio = "La <b>tarifa</b> seleccionada está <span class=\"colred\">cerrada</span> en este período"; break;
+case "cambia il commento":  			$messaggio = "cambiar el comentario"; break;
+case "Il commento":  				$messaggio = "El comentario"; break;
+case "verrà cambiato":  			$messaggio = "será cambiado"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
