@@ -359,7 +359,7 @@ case "Qualsiasi messaggio":  			$messaggio = "Qualquier mensaje"; break;
 case "da":  					$messaggio = "desde"; break;
 case "con oggetto contenete":  			$messaggio = "con asunto que contenga"; break;
 case "I dati per lo scaricamento delle email sono sbagliati o incompleti":	$messaggio = "Los datos para descargar los emails son equivocados o incompletos"; break;
-case "Lo scaricamento delle email di richiesta disponibiltà dal server di posta è stato cambiato":	$messaggio = "La Decarga de los emails de pedido disponibilidad desde el servidor de correo a sido cambiada"; break;
+case "Lo scaricamento delle email di richiesta disponibiltà dal server di posta è stato cambiato":	$messaggio = "La Decarga de los emails de pedido disponibilidad desde el servidor de correo ha sido cambiada"; break;
 case "Colori delle prenotazioni":  		$messaggio = "Colores de las reservas"; break;
 case "Tutto pagato":  				$messaggio = "Todo pagado"; break;
 case "Caparra pagata":  			$messaggio = "Fianza pagada"; break;
@@ -374,6 +374,29 @@ case "tipo":  					$messaggio = "tipo"; break;
 case "booleano":  				$messaggio = "booleano"; break;
 case "testo":  					$messaggio = "texto"; break;
 case "Il campo personalizzato contiene caratteri non consentiti":	$messaggio = "El campo personalizado contiene caracteres no consentidos"; break;
+case "Gestire anche i codici CVC delle carte di credito":	$messaggio = "Gestionar también los códigos CVC de las tarjetas de crédito"; break;
+case "Esonero di responsabilità":  		$messaggio = "Exención de responsabilidad"; break;
+case "la gestione dei codici CVC avverrà sotto la propria responsabilità, essendo a conoscenza che gli standard di sicurezza PCI ne vietano la registrazione":	$messaggio = "La Gestión de los códigos CVC se llevará a cabo bajo su propria responsabilidad, sabiendo que las normas de seguridad PCI prohiben guardarlos"; break;
+case "L'accettazione di questa clausola conferma che gli sviluppatori di questo software sono liberi da ogni responsibilità sulla sicurezza di questi dati":	$messaggio = "La aceptación de esta cláusula confirma que los desarolladores de este software están libres de toda responsabilidad sobre la seguridad de estos datos"; break;
+case "Accetto":  				$messaggio = "Acepto"; break;
+case "Declino":  				$messaggio = "Renuncio"; break;
+case "La gestione dei codici cvc è stata cambiata":	$messaggio = "La Gestión de los códigos CVC ha sido cambiada"; break;
+case "Scegli le righe con i totali da mostrare":	$messaggio = "Escoger cuales líneas con los totales enseñar"; break;
+case "giornaliero":  				$messaggio = "diario"; break;
+case "mensile":  				$messaggio = "mensual"; break;
+case "tabella":  				$messaggio = "tabla"; break;
+case "Le righe da mostrare nelle tabelle delle casse sono state cambiate":	$messaggio = "Las líneas enseñadas en las tablas de las cajas han sido cambiadas"; break;
+case "partenze e prenotazioni correnti":  	$messaggio = "salidas y reservas corrientes"; break;
+case "Commenti personalizzati delle prenotazioni":	$messaggio = "Comentarios personalizados de las reservas"; break;
+case "Commento personalizzato della prenotazione eliminato":	$messaggio = "Comentario personalizado de la reserva eliminado"; break;
+case "Nuovo commento personalizzato della prenotazione aggiunto":	$messaggio = "Nuevo comentario personalizado de la reserva añadido"; break;
+case "Punto vendita ed inventario":  		$messaggio = "Punto de venta e inventario"; break;
+case "Ordinamento nell'inventario e punto vendita":	$messaggio = "Orden en el inventario y punto de venta"; break;
+case "alfabetico":  				$messaggio = "alfabético"; break;
+case "per ordine di inserimento":  		$messaggio = "por orden de inserción"; break;
+case "Tasti per operazioni nel punto vendita":	$messaggio = "Botones para las operaciones en el punto de venta"; break;
+case "L'ordinamento nell'inventario e nel punto vendita è stato cambiato":	$messaggio = "El orden en el inventario y punto de venta ha sido cambiado"; break;
+case "I tasti per operazioni nel punto vendita sono stati cambiati":	$messaggio = "Los botones para las operaciones en el punto de venta han sido cambiados"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
