@@ -48,7 +48,8 @@ case "Possibilità di confermare la prenotazione":	$messaggio = "Posibilidad de
 case "Possibilità di inserire uno sconto":  	$messaggio = "Posibilidad de insertar un descuento"; break;
 case "Possibilità di inserire la caparra e le commissioni":  	$messaggio = "Posibilidad de insertar la fianza y las comisiones"; break;
 case "Possibilità di inserire dei costi aggiuntivi":	$messaggio = "Posibilidad de insertar costes añadidos"; break;
-case "Possibilità di inserire un commento":  	$messaggio = "Posibilidad de insertar un comentario"; break;
+case "Possibilità di inserire il commento":  	$messaggio = "Posibilidad de insertar el comentario"; break;
+case "Possibilità di inserire i commenti personalizzati":	$messaggio = "Posibilidad de insertar los comentarios personalizados"; break;
 case "Possibilità di inserire il numero di persone":	$messaggio = "Posibilidad de insertar el número de personas"; break;
 case "Possibilità di inserire prenotazioni anche in periodi già iniziati":	$messaggio = "Posibilidad de insertar reservas también en períodos ya empezados"; break;
 case "Prenotazioni che possono essere <i>modificate</i>":	$messaggio = "Reservas que pueden ser <i>modificadas</i>"; break;
@@ -61,7 +62,9 @@ case "Possibilità di modificare la tariffa":  	$messaggio = "Posibilidad de mod
 case "Si, con regola 2 a scelta":  		$messaggio = "Si, con la opción de la regla 2"; break;
 case "Si, sempre con regola 2":  		$messaggio = "Si, siempre con regla 2"; break;
 case "Possibilità di modificare il numero delle persone":	$messaggio = "Posibilidad de modificar el número de personas"; break;
+case "Possibilità di vedere il commento":  	$messaggio = "Posibilidad de ver el comentario"; break;
 case "Possibilità di modificare il commento":  	$messaggio = "Posibilidad de modificar el comentario"; break;
+case "Possibilità di vedere e modificare i commenti personalizzati":	$messaggio = "Posibilidad de ver y modificar los comentarios personalizados"; break;
 case "Possibilità di modificare lo sconto":  	$messaggio = "Posibilidad de modificar el descuento"; break;
 case "Possibilità di modificare la caparra e le commissioni":	$messaggio = "Posibilidad de modificar la fianza y las comisiones"; break;
 case "Possibilità di modificare i costi aggiuntivi":	$messaggio = "Posibilidad de modificar los costes añadidos"; break;
@@ -145,8 +148,10 @@ case "non potrà inserire la <b>caparra</b> e le <b>commissioni</b> quando inser
 case "potrà inserire la <b>caparra</b> e le <b>commissioni</b> quando inserisce nuove prenotazioni nel":	$messaggio = "podrá insertar una <b>fianza</b> y las <b>comisiones</b> cuando inserta nuevas reservas en el"; break;
 case "non potrà inserire dei <b>costi aggiuntivi</b> quando inserisce nuove prenotazioni nel":	$messaggio = "no podrá insertar <b>costes añadidos</b> cuando inserta nuevas reservas en el"; break;
 case "potrà inserire dei <b>costi aggiuntivi</b> quando inserisce nuove prenotazioni nel":	$messaggio = "podrá insertar <b>costes añadidos</b> cuando inserta nuevas reservas en el"; break;
-case "non potrà inserire dei <b>commenti</b> quando inserisce nuove prenotazioni nel":	$messaggio = "no podrá insertar <b>comentarios</b> cuando inserta nuevas reservas en el"; break;
-case "potrà inserire dei <b>commenti</b> quando inserisce nuove prenotazioni nel":	$messaggio = "podrá insertar <b>comentarios</b> cuando inserta nuevas reservas en el"; break;
+case "non potrà inserire il <b>commento</b> quando inserisce nuove prenotazioni nel":	$messaggio = "no podrá insertar el <b>comentario</b> cuando inserta nuevas reservas en el"; break;
+case "potrà inserire il <b>commento</b> quando inserisce nuove prenotazioni nel":	$messaggio = "podrá insertar el <b>comentario</b> cuando inserta nuevas reservas en el"; break;
+case "non potrà inserire i <b>commenti personalizzati</b> quando inserisce nuove prenotazioni nel":	$messaggio = "no podrá insertar los <b>comentarios personalizados</b> cuando inserta nuevas reservas en el"; break;
+case "potrà inserire i <b>commenti personalizzati</b> quando inserisce nuove prenotazioni nel":	$messaggio = "podrá insertar los <b>comentarios personalizados</b> cuando inserta nuevas reservas en el"; break;
 case "non potrà inserire il <b>numero delle persone</b> quando inserisce nuove prenotazioni nel":	$messaggio = "no podrá insertar el <b>número de las personas</b> cuando inserta nuevas reservas en el"; break;
 case "potrà inserire il <b>numero delle persone</b> quando inserisce nuove prenotazioni nel":	$messaggio = "podrá insertar el <b>número de las personas</b> cuando inserta nuevas reservas en el"; break;
 case "non potrà inserire nuove prenotazioni in <b>periodi già iniziati</b> nel":	$messaggio = "no podrá insertar nuevas reservas en <b>períodos ya empezados</b> en el"; break;
@@ -161,8 +166,12 @@ case "non potrà modificare la <b>tariffa</b> delle prenotazioni nel":	$messaggi
 case "potrà modificare la <b>tariffa</b> delle prenotazioni, scegliendo se utilizzare la regola 2, nel":	$messaggio = "podrá modificar la <b>tarifa</b> de las reservas, escogiendo si utilizar la regla 2, en el"; break;
 case "non potrà modificare il <b>numero delle persone</b> delle prenotazioni nel":	$messaggio = "no podrá modificar el <b>número de las personas</b> de las reservas en el"; break;
 case "potrà modificare il <b>numero delle persone</b> delle prenotazioni nel":	$messaggio = "podrá modificar el <b>número de las personas</b> de las reservas en el"; break;
+case "non potrà vedere il <b>commento</b> delle prenotazioni nel":	$messaggio = "no podrá ver el <b>comentario</b> de las reservas en el"; break;
+case "potrà vedere il <b>commento</b> delle prenotazioni nel":	$messaggio = "podrá ver el <b>comentario</b> de las reservas en el"; break;
 case "non potrà modificare il <b>commento</b> delle prenotazioni nel":	$messaggio = "no podrá modificar el <b>comentario</b> de las reservas en el"; break;
 case "potrà modificare il <b>commento</b> delle prenotazioni nel":	$messaggio = "podrá modificar el <b>comentario</b> de las reservas en el"; break;
+case "non potrà vedere e modificare i <b>commenti personalizzati</b> delle prenotazioni nel":	$messaggio = "no podrá ver y modificar los <b>comentarios personalizados</b> de las reservas en el"; break;
+case "potrà vedere e modificare i <b>commenti personalizzati</b> delle prenotazioni nel":	$messaggio = "podrá ver y modificar los <b>comentarios personalizados</b> de las reservas en el"; break;
 case "non potrà modificare lo <b>sconto</b> delle prenotazioni nel":	$messaggio = "no podrá modificar el <b>descuento</b> de las reservas en el"; break;
 case "potrà modificare lo <b>sconto</b> delle prenotazioni nel":	$messaggio = "podrá modificar el <b>descuento</b> de las reservas en el"; break;
 case "non potrà modificare la <b>caparra</b> e le <b>commissioni</b> delle prenotazioni nel":	$messaggio = "no podrá modificar la <b>fianza</b> y las <b>comisiones</b> de las reservas en el"; break;
@@ -318,10 +327,10 @@ case "potrà modificare i <b>documenti</b>":  	$messaggio = "podrá modificar lo
 case "non potrà più modificare i <b>documenti</b>":	$messaggio = "ya no podrá modificar los <b>documentos</b>"; break;
 case "Possibilità di vedere email, telefoni e fax dei clienti":	$messaggio = "Posibilidad de ver emails, teléfonos y faxes de los clientes"; break;
 case "Possibilità di vedere l'indirizzo dei clienti":	$messaggio = "Posibilidad de ver la dirección de los clientes"; break;
-case "potrà vedere <b>email, telefoni e fax</b> dei clienti":	$messaggio = "podrà ver <b>emails, teléfonos y faxes</b> de los clientes"; break;
-case "non potrà più vedere <b>email, telefoni e fax</b> dei clienti":	$messaggio = "ya no podrà ver <b>emails, teléfonos y faxes</b> de los clientes"; break;
-case "potrà vedere <b>l'indirizzo</b> dei clienti":	$messaggio = "podrà ver <b>la dirección</b> de los clientes"; break;
-case "non potrà più vedere <b>l'indirizzo</b> dei clienti":	$messaggio = "ya no podrà ver <b>la dirección</b> de los clientes"; break;
+case "potrà vedere <b>email, telefoni e fax</b> dei clienti":	$messaggio = "podrá ver <b>emails, teléfonos y faxes</b> de los clientes"; break;
+case "non potrà più vedere <b>email, telefoni e fax</b> dei clienti":	$messaggio = "ya no podrá ver <b>emails, teléfonos y faxes</b> de los clientes"; break;
+case "potrà vedere <b>l'indirizzo</b> dei clienti":	$messaggio = "podrá ver <b>la dirección</b> de los clientes"; break;
+case "non potrà più vedere <b>l'indirizzo</b> dei clienti":	$messaggio = "ya no podrá ver <b>la dirección</b> de los clientes"; break;
 case "Mostrare le prenotazioni non permesse come":	$messaggio = "Mostrar las reservas no permitidas como"; break;
 case "oscurate":  				$messaggio = "oscurecidas"; break;
 case "periodi vuoti":  				$messaggio = "períodos vacios"; break;
@@ -329,6 +338,12 @@ case "solo correnti e future":  		$messaggio = "solo corrientes y futuras"; brea
 case "vedrà le prenotazioni non permesse come <em>oscurate</em>":	$messaggio = "verá las reservas no permitidas como <em>oscurecidas</em>"; break;
 case "vedrà le prenotazioni non permesse come <em>periodi vuoti</em>":	$messaggio = "verá las reservas no permitidas como <em>períodos vacios</em>"; break;
 case "vedrà le prenotazioni non permesse come <em>periodi vuoti nel passato ed oscurate nel presente e nel futuro</em>":	$messaggio = "verá las reservas no permitidas como <em>períodos vacios en el pasado y oscurecidas en el presente y futuro</em>"; break;
+case "Possibilità di cancellare o sovrascrivere i documenti salvati":	$messaggio = "Posibilidad de borrar o sobrescribir los documentos guardados"; break;
+case "potrà <b>cancellare e sovrascrivere i documenti</b> salvati nel":	$messaggio = "podrá <b>borrar y sobrescribir los documentos</b> guardados en"; break;
+case "non potrà <b>cancellare e sovrascrivere i documenti</b> salvati nel":	$messaggio = "no podrá <b>borrar y sobrescribir los documentos</b> guardados en"; break;
+case "Creazione e modifica delle interconnessioni":	$messaggio = "Creación y modificación de las interconexiones"; break;
+case "potrà creare e modificare le <b>interconnessioni</b>":	$messaggio = "podrá crear y modificar las <b>interconexiones</b>"; break;
+case "non potrà più creare e modificare le <b>interconnessioni</b>":	$messaggio = "ya no podrá crear y modificar las <b>interconexiones</b>"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
