@@ -119,14 +119,14 @@ case "Tariffa":  				$messaggio = "Tarifa"; break;
 case "Inserisci nuove regole":  		$messaggio = "Inserta nuevas reglas"; break;
 case "Il numero inserito esiste già":  		$messaggio = "El número insertado ya existe"; break;
 case "Continua":  				$messaggio = "Continua"; break;
-case "Torna indietro":  			$messaggio = "Vuelve atrás"; break;
+case "Torna indietro":  			$messaggio = "Volver atrás"; break;
 case "Casa":  					$messaggio = "Casa"; break;
 case "Piano":  					$messaggio = "Piso"; break;
 case "Capienza_massima":  			$messaggio = "Capacidad_máxima"; break;
 case "Priorità":  				$messaggio = "Prioridad"; break;
 case "Modifica":  				$messaggio = "Modificar"; break;
 case "modifica":  				$messaggio = "modificar"; break;
-case "Torna al menù principale":  		$messaggio = "Vuelve al menú principal"; break;
+case "Torna al menù principale":  		$messaggio = "Volver al menú principal"; break;
 case "persone":  				$messaggio = "personas"; break;
 case "s":  					$messaggio = "s"; break;
 case "g":  					$messaggio = "d"; break;
