@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2012 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2014 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -25,6 +25,7 @@
 $debug = "off";
 $sec_limite_libsett = "";
 #apd_set_pprof_trace();
+#if (function_exists('ini_set')) @ini_set('xdebug.max_nesting_level',1000000);
 
 
 # Function per passare dalla tabella prenota alle variabili
@@ -218,7 +219,7 @@ return $lista_app;
 
 
 
-if (!function_exists("array_keys")) {
+if (!function_exists('array_keys')) {
 function array_keys($arr,$term="") {
 $t = array();
 while (list($k,$v) = each($arr)) {
@@ -227,7 +228,7 @@ $t[] = $k;
 } # fine while (list($k,$v) = each($arr))
 return $t;
 } # fine function array_keys
-} # fine if (!function_exists("array_keys"))
+} # fine if (!function_exists('array_keys'))
 
 
 
@@ -414,7 +415,7 @@ $prenota_in_app_sett[$app][$num1] = $idp;
 function liberasettimane ($idinizio,$idfine,&$limiti_var,$anno,&$fatto,&$appartamento,$profondita,$app_richiesti,&$app_prenota_id,&$app_orig_prenota_id,&$inizio_prenota_id,&$fine_prenota_id,&$app_assegnabili_id,&$prenota_in_app_sett,&$dati_app,$nome_tab_prenota = "prenota") {
 global $debug;
 
-if ($app_richiesti[',numero,']) {
+if (@is_array($app_richiesti) and $app_richiesti[',numero,']) {
 $app_richiesti_vett = $app_richiesti;
 $idinizio_vett = $idinizio;
 $idfine_vett = $idfine;
@@ -442,11 +443,11 @@ for ($num1 = 0 ; $num1 < $n_vett_app ; $num1++) $app_richiesti[$vett_app[$num1]]
 $idinizio = $idinizio_vett[$app_richiesti_vett['id']];
 $idfine = $idfine_vett[$app_richiesti_vett['id']];
 $appartamento = "";
-} # fine if ($app_richiesti[',numero,'])
+} # fine if (@is_array($app_richiesti) and $app_richiesti[',numero,'])
 else {
 $limiti_var['n_ini'] = $idinizio;
 $limiti_var['n_fine'] = $idfine;
-} # fine else if ($app_richiesti[',numero,'])
+} # fine else if (@is_array($app_richiesti) and $app_richiesti[',numero,'])
 
 if (!@is_array($profondita)) {
 $primo_ciclo = "SI";
