@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2009 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2015 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -148,7 +148,7 @@ $frase[19] = "$parola_settimana";
 $frase[20] = "è";
 $frase[21] = "pien$lettera_a";
 $frase[22] = "Non c'è più disponibilità nel periodo richiesto";
-$frase[23] = "C'è ancora disponibilita";
+$frase[23] = "C'è ancora disponibilità";
 $frase[24] = "nel periodo richiesto";
 $frase[25] = "nei periodi richiesti";
 $frase[26] = "per le tipologie richieste";
