@@ -33,7 +33,10 @@ esegui_query("insert into $tablepersonalizza (idpersonalizza,valpersonalizza,idu
 
 # Prendo i dati dal file se già esistente
 if ($template_file_name[$lingua_modello]) $nome_file = $template_file_name[$lingua_modello];
-else $nome_file = $lingua_modello."_".$template_file_name['en'];
+else {
+$nome_file = mext_rat($template_file_name["ita"],$pag,$lingua_modello);
+if ($nome_file == $template_file_name["en"] or $nome_file == $template_file_name["ita"]) $nome_file = $lingua_modello."_".$template_file_name['en'];
+} # fine else if ($template_file_name[$lingua_modello])
 $SI = mex("SI",$pag);
 $NO = mex("NO",$pag);
 $modello_esistente = "NO";
