@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2013 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2014 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -254,7 +254,7 @@ else echo "<br><small><small>($fr_a_persona)</small></small>";
 } # fine if ($per_persona[$num1])
 echo "$chiusura_tag_font</td>";
 for ($num2 = 0 ; $num2 < $num_colonne_periodi ; $num2++) {
-if ((!$tariffa_colonna_periodo[$num1][$num2] and !$tariffap_colonna_periodo[$num1][$num2]) or $tariffa_colonna_periodo[$num1][$num2] == "c") $tariffa_vedi = "&nbsp;";
+if ((!$tariffa_colonna_periodo[$num1][$num2] and !$tariffap_colonna_periodo[$num1][$num2]) or (string) $tariffa_colonna_periodo[$num1][$num2] == "c") $tariffa_vedi = "&nbsp;";
 else {
 if ($tariffa_colonna_periodo[$num1][$num2]) $tariffa_vedi = punti_in_num($tariffa_colonna_periodo[$num1][$num2],$stile_soldi);
 if ($tariffap_colonna_periodo[$num1][$num2]) {
