@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2011 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2014 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -53,9 +53,9 @@ $priv_mod_doc = substr($priv_mod_pers,2,1);
 $contratti_consentiti = risul_query($privilegi_annuali_utente,0,'contratti_consentiti');
 $attiva_contratti_consentiti = substr($contratti_consentiti,0,1);
 if ($attiva_contratti_consentiti == "s") {
-$contratti_consentiti = explode(",",substr($contratti_consentiti,2));
+$contratti_consentiti = explode(",",$contratti_consentiti);
 unset($contratti_consentiti_vett);
-for ($num1 = 0 ; $num1 < count($contratti_consentiti) ; $num1++) if ($contratti_consentiti[$num1]) $contratti_consentiti_vett[$contratti_consentiti[$num1]] = "SI";
+for ($num1 = 1 ; $num1 < count($contratti_consentiti) ; $num1++) if ($contratti_consentiti[$num1]) $contratti_consentiti_vett[$contratti_consentiti[$num1]] = "SI";
 } # fine if ($attiva_contratti_consentiti == "s")
 } # fine else if (numlin_query($privilegi_annuali_utente) == 0)
 } # fine if ($id_utente != 1)
@@ -96,12 +96,19 @@ if ($trad_var[$mess_vett[1]]) $messaggio = $mess_vett[0]."(".$trad_var[$mess_vet
 return $messaggio;
 } # fine function mex2
 
+$campi_pers_comm = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'campi_pers_comm' and idutente = '$id_utente'");
+if (numlin_query($campi_pers_comm) == 1) {
+$campi_pers_comm = explode(">",risul_query($campi_pers_comm,0,'valpersonalizza'));
+$num_commenti_pers = count($campi_pers_comm);
+} # fine if (numlin_query($campi_pers_comm) == 1)
+else $num_commenti_pers = 0;
 $campi_pers_cliente = esegui_query("select * from $tablepersonalizza where idpersonalizza = 'campi_pers_cliente' and idutente = '$id_utente' ");
 if (numlin_query($campi_pers_cliente)) {
 $campi_pers_cliente = explode(">",risul_query($campi_pers_cliente,0,'valpersonalizza'));
 $num_campi_pers_cliente = count($campi_pers_cliente);
 } # fine if (numlin_query($campi_pers_cliente))
 else $num_campi_pers_cliente = 0;
+$commento_personalizzato_ = mex2("commento_personalizzato")."_";
 $campo_personalizzato_ = mex2("campo_personalizzato")."_";
 include("./includes/variabili_contratto.php");
 
@@ -183,9 +190,9 @@ if (preg_replace("/[A-Za-z0-9_]/","",$nuova_var_pers) != "") $continua = "NO";
 $ultima_parte = explode("_",$nuova_var_pers);
 $ultima_parte = (string) $ultima_parte[(count($ultima_parte) - 1)];
 if ($ultima_parte != "" and preg_replace("/[0-9]/","",$ultima_parte) == "") $continua = "NO";
-if ($var_riserv[$nuova_var_pers] or substr($nuova_var_pers,0,20) == "campo_personalizzato") $continua = "NO";
+if ($var_riserv[$nuova_var_pers] or substr($nuova_var_pers,0,20) == "campo_personalizzato" or substr($nuova_var_pers,0,23) == "commento_personalizzato") $continua = "NO";
 if ($continua == "SI") {
-$tabelle_lock = array("$tablecontratti");
+$tabelle_lock = array($tablecontratti);
 $tabelle_lock = lock_tabelle($tabelle_lock);
 $var_esistente = esegui_query("select * from $tablecontratti where (tipo $LIKE 'var%' and testo $LIKE '$nuova_var_pers') or (tipo $LIKE 'vett%' and testo $LIKE '$nuova_var_pers;%') ");
 if (numlin_query($var_esistente) != 0) $continua = "NO";
@@ -252,6 +259,8 @@ if ($azione[0] == "set" and ($azione[1] == $var_pers_elimina or ($azione[3] == "
 if ($azione[0] == "set" and (($azione[5] == "var" and $azione[6] == $n_var_pers_el) or ($azione[7] == "var" and $azione[8] == $n_var_pers_el))) $elimina_cond_corr = "SI";
 if ($azione[0] == "trunc" and $azione[1] == $var_pers_elimina) $elimina_cond_corr = "SI";
 if ($azione[0] == "oper" and ($azione[1] == $var_pers_elimina or $azione[2] == $n_var_pers_el or ($azione[4] == "var" and $azione[5] == $n_var_pers_el))) $elimina_cond_corr = "SI";
+if ($azione[0] == "date" and ($azione[1] == $var_pers_elimina or $azione[2] == $n_var_pers_el)) $elimina_cond_corr = "SI";
+if ($azione[0] == "opdat" and ($azione[1] == $var_pers_elimina or $azione[3] == $n_var_pers_el or $azione[4] == $n_var_pers_el)) $elimina_cond_corr = "SI";
 if ($elimina_cond_corr == "SI") {
 $num_cond = risul_query($condizioni,$num1,'numero');
 $tipo_cond = risul_query($condizioni,$num1,'tipo');
@@ -422,6 +431,7 @@ $continua = "SI";
 if ($inizializza != "rpt" and $inizializza != "inr" and $inizializza != "ind") $continua = "NO";
 if (strcmp($cond_sempre,"") and $cond_sempre != "SI" and $cond_sempre != "NO") $continua = "NO";
 if ($azione != "set" and $azione != "trunc" and $azione != "oper" and $azione != "date" and $azione != "unset" and $azione != "array" and $azione != "break" and $azione != "cont") $continua = "NO";
+if ($oper_data and $azione = "date") $azione = "opdat";
 if ($num_se < 1 or $num_se > 80) $continua = "NO";
 if ($num_se > 1 and $and_or != "and" and $and_or != "or") $continua = "NO";
 if ($continua == "SI") {
@@ -533,6 +543,13 @@ if ($num_giorni and $oper_giorni == "-") $num_giorni = ($num_giorni * -1);
 if ($tipo_giorni != "g" and $tipo_giorni != "m" and $tipo_giorni != "a") $continua = "NO";
 $testo .= "date#%?$var_data#%?$var_data2#%?$subdata#%?$num_giorni#%?$tipo_giorni";
 } # fine if ($azione == "date")
+if ($azione == "opdat") {
+controlla_var_allora($var_data,$continua,$contr_cond);
+controlla_var_se($var_opdat2,$continua,$var_predef,$num_var_predef,$contr_cond);
+controlla_var_se($var_opdat3,$continua,$var_predef,$num_var_predef,$contr_cond);
+if ($tipo_int != "g" and $tipo_int != "m" and $tipo_int != "a") $continua = "NO";
+$testo .= "opdat#%?$var_data#%?$tipo_int#%?$var_opdat2#%?$var_opdat3";
+} # fine if ($azione == "opdat")
 if ($azione == "unset") {
 if (substr($arr_azz,0,1) != "a") $continua = "NO";
 controlla_var_allora($arr_azz,$continua,$contr_cond);
@@ -548,7 +565,7 @@ $var_arr_pers = $arr_pers_vett[1];
 $var_non_predef = esegui_query("select numero from $tablecontratti where (tipo = 'var' or tipo = 'var$contr_cond') and testo = '".aggslashdb($var_arr_pers)."' ");
 if (!numlin_query($var_non_predef)) $continua = "NO";
 } # fine if (numlin_query($arr_esistente) != 1)
-if ($tipo_arr != "dat" and $tipo_arr != "val" and $tipo_arr != "cop") $continua = "NO";
+if ($tipo_arr != "dat" and $tipo_arr != "dap" and $tipo_arr != "val" and $tipo_arr != "cop") $continua = "NO";
 if ($tipo_arr == "val") $lista_val = controlla_testo_input($lista_val);
 else $lista_val = "";
 if ($tipo_arr == "cop") {
@@ -966,6 +983,21 @@ $tipo_giorni = $azione[5];
 } # fine if ($num_cond_mod == $num_cond)
 } # fine if ($azione[0] == "date")
 
+if ($azione[0] == "opdat") {
+$str_cond .= mex("porre",$pag)." [".$nome_var[$azione[1]]."] ".mex("uguale al numero di",$pag)." \"";
+if ($azione[2] == "g") $str_cond .= mex("giorni",$pag);
+if ($azione[2] == "m") $str_cond .= mex("mesi",$pag);
+if ($azione[2] == "a") $str_cond .= mex("anni",$pag);
+$str_cond .= "\" ".mex("dalla data",$pag)." [".mex2($azione[3])."]";
+$str_cond .= " ".mex("alla data",$pag)." [".mex2($azione[4])."]";
+if ($num_cond_mod == $num_cond) {
+$var_data = $azione[1];
+$tipo_int = $azione[2];
+$var_opdat2 = $azione[3];
+$var_opdat3 = $azione[4];
+} # fine if ($num_cond_mod == $num_cond)
+} # fine if ($azione[0] == "opdat")
+
 if ($azione[0] == "unset") {
 $str_cond .= mex("azzera l'array",$pag)." [".$nome_var[$azione[1]]."]";
 if ($num_cond_mod == $num_cond) $arr_azz = $azione[1];
@@ -974,6 +1006,7 @@ if ($num_cond_mod == $num_cond) $arr_azz = $azione[1];
 if ($azione[0] == "array") {
 $str_cond .= mex("assegna all'array",$pag)." [".$nome_var[$azione[1]]."] ";
 if ($azione[2] == "dat") $str_cond .= mex("valori progressivi tra le date selezionate",$pag);
+if ($azione[2] == "dap") $str_cond .= mex("valori progressivi tra il primo arrivo e l'ultima partenza",$pag);
 if ($azione[2] == "val") $str_cond .= mex("i valori",$pag)." \"".htmlspecialchars(str_replace(",",", ",$azione[3]))."\"";
 if ($azione[2] == "cop") $str_cond .= mex("i valori dell'array",$pag)." [".$nome_var[$azione[3]]."]";
 if ($num_cond_mod == $num_cond) {
@@ -1337,8 +1370,12 @@ echo "<table><tr onclick=\"document.getElementById('az_oper').checked='1'\"><td>
 (".mex("Utilizzare una variabile personalizzata che finisce con \"_p\" per aggiungervi i separatori delle migliaia e 2 decimali dopo l'operazione",$pag).")
 </small></td></tr></table><br>";
 
-if ($azione == "date") $chk_az = " checked";
+if ($azione == "date" or $azione == "opdat") $chk_az = " checked";
 else $chk_az = "";
+$chk_opdat0 = "";
+$chk_opdat1 = "";
+if ($azione == "opdat") $chk_opdat1 = " checked";
+else $chk_opdat0 = " checked";
 $sel_gi = "";
 $sel_me = "";
 $sel_an = "";
@@ -1356,18 +1393,25 @@ $sel_men = "";
 if ($oper_giorni == "+") $sel_piu = " selected";
 if ($oper_giorni == "-") $sel_men = " selected";
 if (!strcmp($num_giorni,"")) $num_giorni = "0";
-$sel_g = "";
-$sel_m = "";
-$sel_a = "";
 if ($tipo_giorni == "g") $sel_g = " selected";
 if ($tipo_giorni == "m") $sel_m = " selected";
 if ($tipo_giorni == "a") $sel_a = " selected";
+$sel_ig = "";
+$sel_im = "";
+$sel_ia = "";
+if ($tipo_int == "g") $sel_ig = " selected";
+if ($tipo_int == "m") $sel_im = " selected";
+if ($tipo_int == "a") $sel_ia = " selected";
 echo "<table><tr onclick=\"document.getElementById('az_date').checked='1'\"><td>
 <input type=\"radio\" id=\"az_date\" name=\"azione\" value=\"date\"$chk_az>
 </td><td>".ucfirst(mex("porre",$pag))." </td><td><select name=\"var_data\">
 ".str_replace("\"$var_data\">","\"$var_data\" selected>",$option_var_pers)."
-</select></td><td>".str_replace(" ","&nbsp;",mex("uguale a",$pag))."</td><td>
-<select name=\"subdata\">
+</select></td><td>".str_replace(" ","&nbsp;",mex("uguale a",$pag))."</td>
+<td><b style=\"font-size: 260%;\">{</b></td><td>
+<table cellspacing=\"0\"><tr><td>
+<table cellspacing=\"0\"><tr onclick=\"document.getElementById('opdat0').checked='1'\"><td>
+<input type=\"radio\" id=\"opdat0\" name=\"oper_data\" value=\"\"$chk_opdat0>
+</td><td><select name=\"subdata\">
 <option value=\"gi\"$sel_gi>".mex("il giorno",$pag)."</option>
 <option value=\"me\"$sel_me>".mex("il mese",$pag)."</option>
 <option value=\"an\"$sel_an>".mex("l'anno",$pag)."</option>
@@ -1389,7 +1433,25 @@ echo "<table><tr onclick=\"document.getElementById('az_date').checked='1'\"><td>
 <option value=\"g\"$sel_g>".mex("giorni",$pag)."</option>
 <option value=\"m\"$sel_m>".mex("mesi",$pag)."</option>
 <option value=\"a\"$sel_a>".mex("anni",$pag)."</option>
-</select></td></tr></table><br>";
+</select></td></tr></table></td></tr><tr><td>
+<table cellspacing=\"0\"><tr onclick=\"document.getElementById('opdat1').checked='1'\"><td>
+<input type=\"radio\" id=\"opdat1\" name=\"oper_data\" value=\"1\"$chk_opdat1>
+</td><td>
+".str_replace(" ","&nbsp;",mex("numero di",$pag))."</td><td>
+<select name=\"tipo_int\">
+<option value=\"g\"$seli_g>".mex("giorni",$pag)."</option>
+<option value=\"m\"$seli_m>".mex("mesi",$pag)."</option>
+<option value=\"a\"$seli_a>".mex("anni",$pag)."</option>
+</select></td><td>
+".str_replace(" ","&nbsp;",mex("dalla data",$pag))."</td><td>
+<select name=\"var_opdat2\">
+".str_replace("\"$var_opdat2\">","\"$var_opdat2\" selected>",$option_var_predef_data)."
+</select></td><td>
+".str_replace(" ","&nbsp;",mex("alla data",$pag))."</td><td>
+<select name=\"var_opdat3\">
+".str_replace("\"$var_opdat3\">","\"$var_opdat3\" selected>",$option_var_predef_data)."
+</select></td></tr></table></td></tr></table>
+</td></tr></table><br>";
 
 if ($option_arr_pers) {
 if ($azione == "unset") $chk_az = " checked";
@@ -1406,9 +1468,11 @@ if ($opt_arr_var_non_predef) {
 if ($azione == "array") $chk_az = " checked";
 else $chk_az = "";
 $chk_dat = "";
+$chk_dap = "";
 $chk_val = "";
 $chk_cop = "";
 if ($tipo_arr == "dat" or !$tipo_arr) $chk_dat = " checked";
+if ($tipo_arr == "dap") $chk_dap = " checked";
 if ($tipo_arr == "val") $chk_val = " checked";
 if ($tipo_arr == "cop") $chk_cop = " checked";
 echo "<table onclick=\"document.getElementById('az_array').checked='1'\"><tr><td>
@@ -1418,9 +1482,13 @@ echo "<table onclick=\"document.getElementById('az_array').checked='1'\"><tr><td
 ".str_replace("\"$array\">","\"$array\" selected>",$opt_arr_var_non_predef)."
 </select></td><td>
 <b style=\"font-size: 260%;\">{</b></td><td>
-<table cellspacing=\"0\"><tr onclick=\"document.getElementById('arr_dat').checked='1'\"><td>
+<table cellspacing=\"0\">
+<tr onclick=\"document.getElementById('arr_dat').checked='1'\"><td>
 <input type=\"radio\" id=\"arr_dat\" name=\"tipo_arr\" value=\"dat\"$chk_dat></td><td>
 ".str_replace(" ","&nbsp;",mex("valori progressivi tra le date selezionate",$pag)." (".mex("nelle ripetizioni vengono considerate solo le prenotazioni nella data valutata",$pag)).").</td></tr>
+<tr onclick=\"document.getElementById('arr_dap').checked='1'\"><td>
+<input type=\"radio\" id=\"arr_dap\" name=\"tipo_arr\" value=\"dap\"$chk_dap></td><td>
+".str_replace(" ","&nbsp;",mex("valori progressivi tra il primo arrivo e l'ultima partenza",$pag)." <small>(".mex("nelle ripetizioni vengono considerate solo le prenotazioni nella data valutata",$pag)).")</small>.</td></tr>
 <tr onclick=\"document.getElementById('arr_val').checked='1'\"><td>
 <input type=\"radio\" id=\"arr_val\" name=\"tipo_arr\" value=\"val\"$chk_val></td><td>
 <table cellspacing=\"0\"><tr><td>
